/*
 * C
 *
 * Copyright 2015-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

#ifndef _LLCOMM_UART
#define _LLCOMM_UART

/* Includes ------------------------------------------------------------------*/

#include "LLCOMM_BUFFERED_CONNECTION.h"
#include "LLCOMM_UART_configuration.h"
#include "r_uart_api.h"

/* Defines and Macros --------------------------------------------------------*/

/*
 * Defines the software FIFO size for transmission used by MicroEJ framework.
 * Default size is 5 bytes.
 */
#ifndef LLCOMM_UART_TX_BUFFER_SIZE
#define LLCOMM_UART_TX_BUFFER_SIZE 5
#endif

/*
 * Defines the software FIFO size for reception used by MicroEJ framework
 * Default size is 1024 bytes.
 */
#ifndef LLCOMM_UART_RX_BUFFER_SIZE
#define LLCOMM_UART_RX_BUFFER_SIZE 1*1024
#endif

/* Structures ----------------------------------------------------------------*/

/*
 * LLCOMM structure used by LLCOMM_UART.c
 * First field must be the MicroEJ framework LLCOMM connection header
 */
typedef struct LLCOMM_UART
{
    // MicroEJ LLCOMM connection header
	struct LLCOMM_BUFFERED_CONNECTION header;

	// Pointer on Synergy UART instance
	const uart_instance_t* comm_uart;

	// Software FIFO size for transmission used by MicroEJ framework
	uint8_t txBuffer[LLCOMM_UART_TX_BUFFER_SIZE];

	// Software FIFO size for reception used by MicroEJ framework
	uint8_t rxBuffer[LLCOMM_UART_RX_BUFFER_SIZE];

} LLCOMM_UART;

/* Public functions ----------------------------------------------------------*/

/*
 * Generic UART interrupt callback
 */
void LLCOMM_UART_callback(uart_callback_args_t * p_args, LLCOMM_UART* llcomm);

/* EOF -----------------------------------------------------------------------*/

#endif  // _LLCOMM_UART
