/*
 * C
 *
 * Copyright 2015-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/* Includes ------------------------------------------------------------------*/

#include "LLCOMM_UART.h"
#define   LLCOMM_BUFFERED_CONNECTION_IMPL LLCOMM_UART
#include "LLCOMM_BUFFERED_CONNECTION_impl.h"
#include "tx_api.h"
#include "hal_data.h"
#include "../../../synergy/ssp/src/driver/r_sci_common/r_sci_private.h"

/* Private functions ---------------------------------------------------------*/

static void LLCOMM_UART_reset(LLCOMM_BUFFERED_CONNECTION* env)
{
    LLCOMM_BUFFERED_CONNECTION_IMPL_disableTX(env);
    LLCOMM_BUFFERED_CONNECTION_IMPL_disableRX(env);
    LLCOMM_BUFFERED_CONNECTION_IMPL_disableTXDeviceInterrupt(env);
    LLCOMM_BUFFERED_CONNECTION_IMPL_disableRXDeviceInterrupt(env);
}

/* Interrupt callback --------------------------------------------------------*/

/*
 * Generic interrupt callback
 */
void LLCOMM_UART_callback(uart_callback_args_t * p_args, LLCOMM_UART* llcomm)
{
    if (p_args->event == UART_EVENT_RX_CHAR)
    {
        // data received: send it to MicroEJ framework
        LLCOMM_BUFFERED_CONNECTION_dataReceived((LLCOMM_BUFFERED_CONNECTION*)&llcomm->header, (int32_t)p_args->data);
    }

    if (p_args->event == UART_EVENT_TX_COMPLETE)
    {
        // transmit FIFO is not full: notify MicroEJ framework
        LLCOMM_BUFFERED_CONNECTION_transmitBufferReady((LLCOMM_BUFFERED_CONNECTION*)&llcomm->header);
    }
}

/* Public functions ----------------------------------------------------------*/

void LLCOMM_BUFFERED_CONNECTION_IMPL_initialize(LLCOMM_BUFFERED_CONNECTION* env)
{
    // force to reset the UART driver state
    LLCOMM_UART_reset(env);
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getPlatformId(LLCOMM_BUFFERED_CONNECTION* env)
{
    // platform ID is the Synergy UART driver channel value
    return (int32_t)(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel);
}

void* LLCOMM_BUFFERED_CONNECTION_IMPL_getName(LLCOMM_BUFFERED_CONNECTION* env)
{
    // this kind of connection cannot be open from a name (only from a platform port number)
    return 0;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_configureDevice(LLCOMM_BUFFERED_CONNECTION* env, int32_t baudrate, int32_t bitsperchar, int32_t stopbits, int32_t parity)
{
    /*
     * We don't want to use the generated default UART configuration. So we set our own configuration.
     * Nevertheless, the following line throws a compilation error:
     *
     * ((LLCOMM_UART*)env)->comm_uart->p_cfg->parity = UART_PARITY_ODD;
     *
     * because the structure "p_cfg" is a "const". So we create a local copy of this structure, set
     * our configuration and open the UART driver with this local configuration.
     */

    // copy configuration
    uart_cfg_t p_cfg_copy;           // copy of configuration
    memcpy((void*)&p_cfg_copy, (void*)((LLCOMM_UART*)env)->comm_uart->p_cfg, sizeof(uart_cfg_t));

    // now, set our configuration

    // get number of bits
    switch (bitsperchar)
    {
        default:
        case LLCOMM_BUFFERED_CONNECTION_DATABITS_5:
        case LLCOMM_BUFFERED_CONNECTION_DATABITS_6:
            // not available
            return LLCOMM_BUFFERED_CONNECTION_ERROR_INIT_UNSUPPORTED_BITSPERCHAR;

        case LLCOMM_BUFFERED_CONNECTION_DATABITS_7:
            p_cfg_copy.data_bits = UART_DATA_BITS_7;
            break;

        case LLCOMM_BUFFERED_CONNECTION_DATABITS_8:
            p_cfg_copy.data_bits = UART_DATA_BITS_8;
            break;

        case LLCOMM_BUFFERED_CONNECTION_DATABITS_9:
            p_cfg_copy.data_bits = UART_DATA_BITS_9;
            break;
    }

    // get number of stop bits
    switch (stopbits)
    {
        case LLCOMM_BUFFERED_CONNECTION_STOPBITS_1:
            p_cfg_copy.stop_bits = UART_STOP_BITS_1;
            break ;

        case LLCOMM_BUFFERED_CONNECTION_STOPBITS_2:
            p_cfg_copy.stop_bits = UART_STOP_BITS_2;
            break ;

        default:
            return LLCOMM_BUFFERED_CONNECTION_ERROR_INIT_UNSUPPORTED_STOPBITS;
    }

    // get parity
    switch (parity)
    {
        case LLCOMM_BUFFERED_CONNECTION_PARITY_EVEN:
            p_cfg_copy.parity = UART_PARITY_EVEN;
            break ;

        case LLCOMM_BUFFERED_CONNECTION_PARITY_NO:
            p_cfg_copy.parity = UART_PARITY_OFF;
            break ;

        case LLCOMM_BUFFERED_CONNECTION_PARITY_ODD:
            p_cfg_copy.parity = UART_PARITY_ODD;
            break ;

        default:
            return LLCOMM_BUFFERED_CONNECTION_ERROR_INIT_UNSUPPORTED_PARITY;
    }

    // set baudrate
    p_cfg_copy.baud_rate = (uint32_t)baudrate;

    // open UART with our configuration
    ssp_err_t ret = ((LLCOMM_UART*)env)->comm_uart->p_api->open( ((LLCOMM_UART*)env)->comm_uart->p_ctrl,  &p_cfg_copy);

    if (ret == SSP_ERR_HW_LOCKED)
    {
        // already opened: close it before re-open it
        ((LLCOMM_UART*)env)->comm_uart->p_api->close( ((LLCOMM_UART*)env)->comm_uart->p_ctrl);
        ret = ((LLCOMM_UART*)env)->comm_uart->p_api->open( ((LLCOMM_UART*)env)->comm_uart->p_ctrl,  &p_cfg_copy);
    }

    if (ret != SSP_SUCCESS)
    {
        // unknown error
        return LLCOMM_BUFFERED_CONNECTION_ERROR_CANNOT_OPEN;
    }

    // force to reset the UART driver state
    LLCOMM_UART_reset(env);

    return LLCOMM_BUFFERED_CONNECTION_SUCCESS;
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_enableRX(LLCOMM_BUFFERED_CONNECTION* env)
{
    HW_SCI_ReceiverEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_disableRX(LLCOMM_BUFFERED_CONNECTION* env)
{
    HW_SCI_ReceiverDisable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_enableRXDeviceInterrupt(LLCOMM_BUFFERED_CONNECTION* env)
{
    // set RX of SCI register
    HW_SCI_InterruptEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel, SCI_RX_INT, true);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_disableRXDeviceInterrupt(LLCOMM_BUFFERED_CONNECTION* env)
{
    // reset RX of SCI register
    HW_SCI_InterruptEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel, SCI_RX_INT, false);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_enableTX(LLCOMM_BUFFERED_CONNECTION* env)
{
    HW_SCI_TransmitterEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_disableTX(LLCOMM_BUFFERED_CONNECTION* env)
{
    // reset TXI of SCI register
    HW_SCI_TransmitterDisable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_enableTXDeviceInterrupt(LLCOMM_BUFFERED_CONNECTION* env)
{
    // set TXI of SCI register
    HW_SCI_InterruptEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel, SCI_TX_INT, true);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_disableTXDeviceInterrupt(LLCOMM_BUFFERED_CONNECTION* env)
{
    // reset TXI of SCI register
    HW_SCI_InterruptEnable(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel, SCI_TX_INT, false);
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getRXBufferStartAddress(LLCOMM_BUFFERED_CONNECTION* env)
{
    // return MicroEJ framework FIFO for reception
    return (int32_t)(((LLCOMM_UART*)env)->rxBuffer);
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getRXBufferLength(LLCOMM_BUFFERED_CONNECTION* env)
{
    return LLCOMM_UART_RX_BUFFER_SIZE;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getTXBufferStartAddress(LLCOMM_BUFFERED_CONNECTION* env)
{
    // return MicroEJ framework FIFO for transmission
    return (int32_t)(((LLCOMM_UART*)env)->txBuffer);
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getTXBufferLength(LLCOMM_BUFFERED_CONNECTION* env)
{
    return LLCOMM_UART_TX_BUFFER_SIZE;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_useTXHardwareFIFO(LLCOMM_BUFFERED_CONNECTION* env)
{
    return LLCOMM_BUFFERED_CONNECTION_SUCCESS;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_txFifoFull(LLCOMM_BUFFERED_CONNECTION* env)
{
    // check Transmit FIFO Data Count of FIFO Data Register
    return SCI_REG(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel)->FDR_b.T >= SCI_FIFO_STAGE_NUM ? LLCOMM_BUFFERED_CONNECTION_HARDWARE_FIFO_FULL : LLCOMM_BUFFERED_CONNECTION_HARDWARE_FIFO_NOT_FULL;
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_sendData(LLCOMM_BUFFERED_CONNECTION* env, int32_t data)
{
    // fill FIFO Transmit Data Register
    SCI_REG(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel)->FTDR = (uint16_t)data;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_isTransmissionComplete(LLCOMM_BUFFERED_CONNECTION* env)
{
    // check Transmit End Flag of SSR_FIFO register
    return SCI_REG(((LLCOMM_UART*)env)->comm_uart->p_cfg->channel)->SSR_FIFO_b.TEND ? LLCOMM_BUFFERED_CONNECTION_TRANSMISSION_COMPLETE : LLCOMM_BUFFERED_CONNECTION_TRANSMISSION_TIMEOUT;
}

int32_t LLCOMM_BUFFERED_CONNECTION_IMPL_getNbProperties(LLCOMM_BUFFERED_CONNECTION* env)
{
    // This implementation does not provide Device properties
    return 0;
}

void* LLCOMM_BUFFERED_CONNECTION_IMPL_getProperty(LLCOMM_BUFFERED_CONNECTION* env, void* propertyName)
{
    // This implementation does not provide Device properties
    return 0;
}

void* LLCOMM_BUFFERED_CONNECTION_IMPL_getPropertyName(LLCOMM_BUFFERED_CONNECTION* env, int32_t propertyId)
{
    // This implementation does not provide Device properties
    while(1);
}

void LLCOMM_BUFFERED_CONNECTION_IMPL_released(LLCOMM_BUFFERED_CONNECTION* env)
{
    // This implementation does not support dynamic connections add/removal.
    // To enable dynamic connections, synchronization functions must be implemented.
    // See LLCOMM_impl.h
    while(1);
}

