/*
 * C
 *
 * Copyright 2015-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * This file manages all LLCOMM instances (UART, USB etc.). It does the match
 * between Synergy project configuration and generic MicroEJ LLCOMM drivers.
 */

/* Includes ------------------------------------------------------------------*/

#include <stdint.h>
#include "LLCOMM_UART.h"
#include "LLCOMM_impl.h"
#include "microej_core.h"

/* Methods declaration -------------------------------------------------------*/

void LLCOMM_UART_new(LLCOMM_BUFFERED_CONNECTION* env);

/* Enumerations --------------------------------------------------------------*/

/*
 * Defines the mapping between the Synergy UART instance and MicroEJ LLCOMM_UARTs
 * table. The indexes are 0-based.
 */
typedef enum
{
    UART8_INDEX = 0,
    UART4_INDEX = 1,
    UART3_INDEX = 2,
} synergy_to_microej_uart_table;


/* Fields --------------------------------------------------------------------*/

/*
 * Array of all LLCOMM UARTs.
 */
static LLCOMM_UART LLCOMM_UARTs[3];

/* Private functions ---------------------------------------------------------*/

/*
 * Initialize LLCOMM_UARTs array for a specific Synergy UART instance and initialize
 * corresponding MicroEJ LLCOMM_UART.
 */
static void COMMS_initialize_llcomm_uart(int32_t index, const uart_instance_t* comm_uart)
{
    // store Synergy UART instance
    LLCOMM_UARTs[index].comm_uart = comm_uart;

    // create MicroEJ UART connection
    LLCOMM_UART_new(&LLCOMM_UARTs[index].header);

    // add MicroEJ UART connection into MicroEJ framework as generic connection
    LLCOMM_addConnection((LLCOMM_CONNECTION*)&LLCOMM_UARTs[index].header);
}

/* Interrupts callbacks ------------------------------------------------------*/


/*
 * Synergy UART 8 callback
 */
void uart_8_callback(uart_callback_args_t * p_args)
{
    LLCOMM_UART_callback(p_args, &LLCOMM_UARTs[UART8_INDEX]);
}


/*
 * Synergy UART 4 callback
 */
void uart_4_callback(uart_callback_args_t * p_args)
{
    LLCOMM_UART_callback(p_args, &LLCOMM_UARTs[UART4_INDEX]);
}


/*
 * Synergy UART 3 callback
 */
void uart_3_callback(uart_callback_args_t * p_args)
{
    LLCOMM_UART_callback(p_args, &LLCOMM_UARTs[UART3_INDEX]);
}

/* Public functions ----------------------------------------------------------*/

/*
 * Initialize MicroEJ LLCOMM framework.
 */
void LLCOMM_IMPL_initialize(void)
{
    // add Synergy UART 8
    COMMS_initialize_llcomm_uart(UART8_INDEX, &comm_uart_8);
    // add Synergy UART 4
    COMMS_initialize_llcomm_uart(UART4_INDEX, &comm_uart_4);
    // add Synergy UART 3
    COMMS_initialize_llcomm_uart(UART3_INDEX, &comm_uart_3);
}

void LLCOMM_IMPL_syncConnectionsEnter(void)
{
	// Does nothing by default. This implementation does not support dynamic connections.
}

void LLCOMM_IMPL_syncConnectionsExit(void)
{
	// Does nothing by default. This implementation does not support dynamic connections.
}

/* EOF -----------------------------------------------------------------------*/


