/*
 * C
 *
 * Copyright 2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * FIXME
 *
 * This file considers
 * - the timer input clock is PLL / 2 = 120Mhz
 * - the timer period is 1000ms
 *
 * These information must be retrieved in framework in order to not
 * use hardcoded values.
 */

/* Includes ------------------------------------------------------------------*/

#include <stdint.h>
#include "microej_core.h"

/* Globals -------------------------------------------------------------------*/

// this value is updated at each interrupt
static volatile int64_t software_counter ;

/* Private functions ---------------------------------------------------------*/

/**
 * @brief this function get counter value and return a number a us
 *
 * @attention this function assume that PLL/2 is 120 Mhz
 *
 * @return
 */
static int64_t timer_get_counter_value(void)
{
    timer_size_t value;
    core_hardware_timer.p_api->counterGet(core_hardware_timer.p_ctrl, &value);

    /* we must return us, assume that PLL/2 == 120 MHz */
    return ((int64_t)value / 120) ; // XXX hardcoded value, see file comment
}

static int64_t time_hardware_timer_getTicks(void)
{
	return software_counter + timer_get_counter_value();
}

/*
 * An interrupt can occur between the reading of software_counter
 * and timer_get_counter_value(). So the value of software_counter is not
 * coherent with the value of timer_get_counter_value().
 * Compute twice the ticks value. At least one will be correct.
 */
static int64_t time_hardware_timer_getAndCheckTicks(void)
{
	volatile int64_t val1 = time_hardware_timer_getTicks();
	volatile int64_t val2 = time_hardware_timer_getTicks();

	if(val2 < val1)
	{	// second computation get back in the past: val2 is not valid for sure
		return val1;
	}
	else
	{	// first computation may be invalid (to far in the past): val2 is valid for sure
		return val2;
	}
}


/* Callback functions --------------------------------------------------------*/

/**
 * @brief this function is a callback used when hardware timer overflowed (each second)
 * @param p_args useless
 */
void hardware_timer_callback(timer_callback_args_t * p_args)
{
    software_counter += 1000000;     // XXX hardcoded value, see file comment
}

/* Public functions ----------------------------------------------------------*/

void time_hardware_timer_initialize(void)
{
    software_counter = 0;
    core_hardware_timer.p_api->open(core_hardware_timer.p_ctrl, core_hardware_timer.p_cfg);
}

/**
 * @brief this function return the total number of ms until start of card
 *
 * @return
 */
int64_t time_hardware_timer_getCurrentTime(void)
{
    return time_hardware_timer_getAndCheckTicks()/1000 ;
}

/**
 * @brief this function return the total number of ns until start of card
 *
 * @return
 */
int64_t time_hardware_timer_getTimeNanos(void)
{
    return time_hardware_timer_getAndCheckTicks()*1000 ;
}
