/**
 * C
 *
 * Copyright 2015-2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 * This module provides adaptation layer for implementation specific functions.
 * of delegate Fs processing module
 *
 */

//#define FS_ADAPT_PRINT_ERROR

#ifdef FS_ADAPT_PRINT_ERROR
#include <stdio.h>
#endif
#include <string.h>
#include "tx_api.h"
#include "fs_delegate_thread.h"
#include "pool.h"
#include "fs_helper_os.h"
#include "LLFS_impl.h"



extern TX_THREAD fs_delegate_thread;

/** @brief private pool file */
static FS_ADAPT_FIL gpst_pool_file[FS_MAX_NUMBER_OF_FILE_IN_POOL];
static POOL_item_status_t gpst_pool_file_item_status[FS_MAX_NUMBER_OF_FILE_IN_POOL];
static POOL_ctx_t gst_pool_file_ctx =
{
	gpst_pool_file,
	gpst_pool_file_item_status,
	sizeof(FS_ADAPT_FIL),
	sizeof(gpst_pool_file)/sizeof(FS_ADAPT_FIL)
};

/** @brief private pool directory */
static FS_ADAPT_DIR gpst_pool_dir[FS_MAX_NUMBER_OF_DIR_IN_POOL];
static POOL_item_status_t gpst_pool_dir_item_status[FS_MAX_NUMBER_OF_DIR_IN_POOL];
static POOL_ctx_t gst_pool_dir_ctx =
{
	gpst_pool_dir,
	gpst_pool_dir_item_status,
	sizeof(FS_ADAPT_DIR),
	sizeof(gpst_pool_dir)/sizeof(FS_ADAPT_DIR)
};

FS_ADAPT_status_t FS_ADAPT_init_f(void)
{
	FS_ADAPT_status_t e_return = FS_ADAPT_NO_ERROR;

	/* init fx (theoricaly auto generated) */

	/* init private pool */
	memset(gpst_pool_file, 0, sizeof(gpst_pool_file));
	memset(gpst_pool_file_item_status, POOL_FREE, sizeof(gpst_pool_file_item_status));

	memset(gpst_pool_dir, 0, sizeof(gpst_pool_dir));
	memset(gpst_pool_dir_item_status, POOL_FREE, sizeof(gpst_pool_dir_item_status));

	return(e_return);
}

FS_ADAPT_status_t FS_ADAPT_start_f(void)
{
	/* this step is theorically all auto generated, and then in fileX case
	 * nothing must be done in this initialization
	 */
	tx_thread_resume(&fs_delegate_thread);
	return FS_ADAPT_NO_ERROR;
}

FS_ADAPT_status_t FS_ADAPT_get_java_thread(unsigned long * _pul_java_thread)
{
	FS_ADAPT_status_t e_return;
	int32_t i32_java_thread;
	i32_java_thread = SNI_getCurrentJavaThreadID();

	if ((_pul_java_thread != NULL) && (i32_java_thread != SNI_ERROR))
	{
		* _pul_java_thread = (unsigned long)i32_java_thread;
		e_return = FS_ADAPT_NO_ERROR;
	}
	else
	{
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] : cannot get java thread (error %d)\n", __FILE__, __LINE__, i32_java_thread);
		#endif
		e_return = FS_ADAPT_ERROR;
	}

	return (e_return);
}

FS_ADAPT_status_t FS_ADAPT_suspend_java_thread (void)
{
	FS_ADAPT_status_t e_return;
	int32_t i32_result;

	i32_result = SNI_suspendCurrentJavaThread(0);

	if (i32_result != SNI_OK)
{
		e_return = FS_ADAPT_ERROR;
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] : cannot suspend java thread (error %d)\n", __FILE__, __LINE__, i32_result);
		#endif
	}
	else
	{
		e_return = FS_ADAPT_NO_ERROR;
	}

	return (e_return);
}

FS_ADAPT_status_t FS_ADAPT_resume_java_thread(unsigned long const _ul_java_thread)
{
	FS_ADAPT_status_t e_return;
	int32_t i32_result;

	i32_result = SNI_resumeJavaThread((int32_t)_ul_java_thread);

	if (i32_result != SNI_OK)
	{
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] : cannot resume java thread (error %d, thread %lu)\n", __FILE__, __LINE__, i32_result, _ul_java_thread);
		#endif
		e_return = FS_ADAPT_ERROR;
	}
	else
	{
		e_return = FS_ADAPT_NO_ERROR;
	}

	return (e_return);
}

FS_ADAPT_status_t FS_ADAPT_post_event_action_f(void * _pv_mailbox, void* _pv_event, unsigned long _ul_timeout)
{
	FS_ADAPT_status_t e_return;
	UINT e_result;

	/* test if mailbox is full */
	if (1)
	{
		/* send event without timeout */

		e_result = tx_queue_send((TX_QUEUE*)(_pv_mailbox), &_pv_event, TX_NO_WAIT);

		/* test if send is ok */
		if (e_result == TX_SUCCESS)
		{
			e_return = FS_ADAPT_NO_ERROR;
		}
		else
		{
			e_return = FS_ADAPT_ERROR;
			#ifdef FS_ADAPT_PRINT_ERROR
				printf("FS_ADAPT_ERROR [%s:%u] : sending error (err %u)\n", __FILE__, __LINE__, e_result);
			#endif
		}
	}
	else
	{
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] : mail box appear full\n", __FILE__, __LINE__);
		#endif
		e_return = FS_ADAPT_ERROR;
	}

	return (e_return);
}


FS_ADAPT_status_t FS_ADAPT_wait_event(void * _pv_mailbox, void** _ppv_event, unsigned long _ul_timeout)
{
	FS_ADAPT_status_t e_return;
	UINT e_result;

	e_result = tx_queue_receive((TX_QUEUE*)(_pv_mailbox), _ppv_event, _ul_timeout);

	/* test received function */
	if (e_result != TX_SUCCESS)
	{
		e_return = FS_ADAPT_ERROR;

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] : task was wake up not properly\n", __FILE__, __LINE__);
		#endif
	}
	else
	{
		e_return = FS_ADAPT_NO_ERROR;
	}

	return (e_return);
}

/**
 * @brief function test if fd given is among file pool fd used
 *
 * @param ui_fd_in fd
 * @return 0 if not found, 1 if found
 */
static unsigned char test_fd_among_file_pool_f(unsigned int ui_fd_in)
{
	unsigned char uc_found = 0;
	int i;

	/* search the fd id in all pool fd */
	for (i=0;(i<sizeof(gpst_pool_file)/sizeof(FS_ADAPT_FIL)) && (uc_found != 1);i++)
	{
		/* test if address is in pool, if yes test if is used in pool */
		if ((&gpst_pool_file[i] == (FS_ADAPT_FIL*)ui_fd_in) && (gpst_pool_file_item_status[i] == POOL_USED))
		{
			/* fd found */
			uc_found = 1;
		}
	}

	return (uc_found);
}

/**
 * @brief function test if fd given is among directory pool fd used
 *
 * @param ui_fd_in fd
 * @param _pi_index_found index found
 * @return 0 if not found, 1 if found
 */
static unsigned char test_fd_among_dir_pool_f(unsigned int ui_fd_in,
											  unsigned int * _pi_index_found)
{
	unsigned char uc_found = 0;
	int i;

	/* search the fd id in all pool fd */
	for (i=0;(i<sizeof(gpst_pool_dir)/sizeof(FS_ADAPT_DIR)) && (uc_found != 1);i++)
	{
		/* test if address is in pool, if yes test if is used in pool */
		if ((&gpst_pool_dir[i] == (FS_ADAPT_DIR*)ui_fd_in) && (gpst_pool_dir_item_status[i] == POOL_USED))
		{
			/* fd found */
			uc_found = 1;
			* _pi_index_found = i;
			break;
		}
	}

	return (uc_found);
}

/***** All private function FS_specific *******/

void FS_ADAPT_close_file_f(unsigned int ui_fd_in,
		                 unsigned char * puc_bool_out)
{
	UINT fs_err;

	if (test_fd_among_file_pool_f(ui_fd_in))
	{
		/* try to close the file */
		fs_err = fx_file_close((FS_ADAPT_FIL*) ui_fd_in);

		if (fs_err != FX_SUCCESS)
		{
			*puc_bool_out = 1;
		}
		else
		{
			*puc_bool_out = 0;
		}

		/* free file pool */
		POOL_free_f(&gst_pool_file_ctx, (void*)ui_fd_in);

		fx_media_flush(&g_fx_media);
	}
	else
	{
		/* error fd not found */
		*puc_bool_out = 1;

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] close file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, ui_fd_in);
		#endif
	}
}

void FS_ADAPT_open_file_f(char* _pc_path_in,
		                      unsigned char _uc_mode_in,
		                      int * _pi_fd_out)
{
	UINT fs_err;
	UINT ui_internal_mode;
	FS_ADAPT_FIL * m_file;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		/* test read or write mode */
		if (_uc_mode_in == (jchar)'R')
		{
			/* write mode */
			ui_internal_mode = FX_OPEN_FOR_READ;
		}
		else
		{
			/* read or append mode */
			ui_internal_mode = FX_OPEN_FOR_WRITE;
		}

		/* manage delete file if write mode but not append (don't care about error) */
		if (_uc_mode_in == (jchar)'W')
		{
			fx_file_delete(&g_fx_media, _pc_path_in);
			fx_media_flush(&g_fx_media);
			fx_file_create(&g_fx_media, _pc_path_in);
		}

		/* test if alloc is ok */
		if (POOL_reserve_f(&gst_pool_file_ctx, (void**)&m_file) == POOL_NO_ERROR)
		{
			/* open file according to internal mode */
			fs_err = fx_file_open(&g_fx_media, m_file, _pc_path_in, ui_internal_mode);

			/* test return function */
			if (fs_err != FX_SUCCESS)
			{
				*_pi_fd_out = LLFS_NOK;  // error
				POOL_free_f(&gst_pool_file_ctx, m_file);
			}
			else
			{
				/* seek at the end of file if append mode or at the start (in case of write close and rewrite) */
				fs_err = fx_file_seek(m_file, (_uc_mode_in == (jchar)'A') ? m_file->fx_file_current_file_size : 0);

				/* test return function */
				if (fs_err != FX_SUCCESS)
				{
					*_pi_fd_out = LLFS_NOK;  // error
					POOL_free_f(&gst_pool_file_ctx, m_file);
				}
				else
				{
					*_pi_fd_out = (int)m_file;  // no error
				}
			}
		}
		else
		{
			*_pi_fd_out = LLFS_NOK;  // error
		}
	}
	else
	{
		*_pi_fd_out = LLFS_NOK;  // error
	}
}

void FS_ADAPT_read_file_f(unsigned int _ui_fd_in,
						              char* _pc_output_buffer_in,
						              unsigned int _ui_data_length_in,
						              int * _pi_error_out)
{
	unsigned long ul_bytesread;
	UINT fs_err;

	/* Test entry function */
	if ((_pc_output_buffer_in != NULL) && (test_fd_among_file_pool_f(_ui_fd_in)))
	{
		/* read */
		fs_err = fx_file_read((FS_ADAPT_FIL*)_ui_fd_in,
							  _pc_output_buffer_in ,
							  _ui_data_length_in,
							  &ul_bytesread);

		/* test return function */
		if (fs_err == FX_END_OF_FILE)
		{
			*_pi_error_out = LLFS_EOF;  // EOF
		}
		else if (fs_err == FX_SUCCESS){
			*_pi_error_out = (int) ul_bytesread;  // Ok
		}
		else
		{
			*_pi_error_out = LLFS_NOK;  // error
		}

		#ifdef FS_ADAPT_DEBUG
					printf("FS_ADAPT_DEBUG [%s:%u] read file content %d - read %d (err %d)\n",  __FILE__, __LINE__, _pc_output_buffer_in, ul_bytesread, fs_err);
		#endif
	}
	else
	{
		*_pi_error_out = LLFS_NOK;  // error

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] write byte file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}


void FS_ADAPT_write_byte_file_f(unsigned int _ui_fd_in,
										int _i_data_in,
										int * _pi_error_out)
{
	UINT fs_err;

	if (test_fd_among_file_pool_f(_ui_fd_in))
	{
		/* read */
		fs_err = fs_err = fx_file_write((FS_ADAPT_FIL*) _ui_fd_in, &_i_data_in , 1);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _pi_error_out = LLFS_NOK; // error
		}
		else
		{
			* _pi_error_out = LLFS_OK; // OK
		}

		fx_media_flush(&g_fx_media);

		#ifdef FS_ADAPT_DEBUG
					printf("FS_ADAPT_DEBUG [%s:%u] write byte file content %d - written %d (err %d)\n",  __FILE__, __LINE__, _i_data_in, * _pi_error_out, fs_err);
		#endif
	}
	else
	{
		* _pi_error_out = LLFS_NOK; // error

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] write byte file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}


void FS_ADAPT_read_byte_file_f(unsigned int _ui_fd_in,
										int * _pi_error_out)
{
	ULONG bytesread;
	unsigned char data;
	UINT fs_err;

	if (test_fd_among_file_pool_f(_ui_fd_in))
	{
		/* read */
		fs_err = fx_file_read((FS_ADAPT_FIL*)_ui_fd_in,
						&data ,
						1,
						&bytesread);

		/* test return function */
		if (fs_err == FX_END_OF_FILE)
		{
			*_pi_error_out = LLFS_EOF;  // EOF
		}
		else if (fs_err == FX_SUCCESS){
			*_pi_error_out = data;  // Ok
		}
		else
		{
			*_pi_error_out = LLFS_NOK;  // error
		}

		#ifdef FS_ADAPT_DEBUG
				printf("FS_ADAPT_DEBUG [%s:%u] read byte file content %d - result %d (err %d)\n",  __FILE__, __LINE__, data, * _pi_error_out, fs_err);
		#endif
	}
	else
	{
		*_pi_error_out = LLFS_NOK;  // error
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] read byte file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}


void FS_ADAPT_skip_file_f(unsigned int _ui_fd_in,
								   long long int _l_n_in,
								   long long int * _pl_error_out)
{
	UINT fs_err;
	FS_ADAPT_FIL* fd = (FS_ADAPT_FIL*)_ui_fd_in;

	if (test_fd_among_file_pool_f(_ui_fd_in))
	{

		ULONG currentPtr = fd->fx_file_current_file_offset;
		ULONG size = fd->fx_file_current_file_size;
		long long int newPtr = currentPtr + _l_n_in;

		// Check for overflow when computing newPtr
		if(_l_n_in > 0)
		{
			if(newPtr < currentPtr)
			{
				// an overflow occurs: saturate the newPtr value
				newPtr = INT64_MAX;
			}
		}
		else
		{
			if(newPtr > currentPtr)
			{
				// an overflow occurs: saturate the newPtr value
				newPtr = INT64_MIN;
			}
		}

		if(newPtr < 0)
		{
			*_pl_error_out = LLFS_NOK; // error
		}
		else
		{
			// limit newPtr value to the size of the file
			if(newPtr > size)
			{
				newPtr = size;
			}

			// Info: cast of newPtr is safe here because 0 <= newPtr <= size
			fs_err = fx_file_seek(fd, (ULONG)newPtr);
			if(fs_err != FX_SUCCESS)
			{
				*_pl_error_out = LLFS_NOK; // error
			}
			else
			{
				*_pl_error_out = newPtr - currentPtr;
			}
		}

		#ifdef FS_ADAPT_DEBUG
			printf("FS_ADAPT_DEBUG [%s:%u] skip file : n=%lld skipped=%lld (err %d)\n",  __FILE__, __LINE__, _l_n_in, * _pl_error_out, fs_err);
		#endif
	}
	else
	{
		*_pl_error_out = LLFS_NOK; // error
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] skip file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}


}


void FS_ADAPT_available_file_f(unsigned int _ui_fd_in,
										int * _pi_error_out)
{

	if (test_fd_among_file_pool_f(_ui_fd_in))
	{

		*_pi_error_out = ((FS_ADAPT_FIL*)_ui_fd_in)->fx_file_current_file_size -  ((FS_ADAPT_FIL*)_ui_fd_in)->fx_file_current_file_offset;

		#ifdef FS_ADAPT_DEBUG
			printf("FS_ADAPT_DEBUG [%s:%u] available file : %d\n",  __FILE__, __LINE__, * _pi_error_out);
		#endif

	}
	else
	{
		*_pi_error_out = LLFS_NOK; // error
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] available file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}


void FS_ADAPT_size_of_file_f(unsigned int _ui_fd_in,
		                         unsigned long * _pul_size_out)
{
	if (test_fd_among_file_pool_f(_ui_fd_in))
	{
		*_pul_size_out = ((FS_ADAPT_FIL*)_ui_fd_in)->fx_file_current_file_size;
	}
	else
	{
		*_pul_size_out = 0; // error
		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] size of file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}

void FS_ADAPT_write_file_f(unsigned int _ui_fd_in,
						               char* _pc_intput_buffer_in,
						               unsigned int _ui_data_length_in,
						               int * _pi_error_out)
{
	UINT fs_err;

	/* Test entry function */
	if ((_pc_intput_buffer_in != NULL) && (test_fd_among_file_pool_f(_ui_fd_in)))
	{
		/* read */
		fs_err = fx_file_write((FS_ADAPT_FIL*) _ui_fd_in, _pc_intput_buffer_in , _ui_data_length_in);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _pi_error_out = LLFS_NOK;  // error
		}
		else
		{
			* _pi_error_out = (int) _ui_data_length_in;
		}

		fx_media_flush(&g_fx_media);
	}
	else
	{
		* _pi_error_out = LLFS_NOK;  // error

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] write file : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}

}

void FS_ADAPT_exist_file_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		fs_err = fx_directory_name_test(&g_fx_media, _pc_path_in);

		/* test return function (ok if it' directory or file else nok)  */
		if ((fs_err == FX_SUCCESS) || (fs_err == FX_NOT_DIRECTORY))
		{
			* _puc_bool_out = 0;
		}
		else
		{
			* _puc_bool_out = 1;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_get_free_space_f(char* _pc_path_in, unsigned long * _pul_size_out)
{
	UINT fs_err;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		fs_err = fx_media_space_available(&g_fx_media, _pul_size_out);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _pul_size_out = 0; //error
		}
		else
		{
			/* nothing to do */
		}
	}
	else
	{
		* _pul_size_out = 0; //error
	}
}

void FS_ADAPT_get_total_space_f(char* _pc_path_in, unsigned long * _pul_size_out)
{
	*_pul_size_out = g_fx_media.fx_media_total_clusters * g_fx_media.fx_media_total_sectors;
}

void FS_ADAPT_get_usable_space_f(char* _pc_path_in, unsigned long * _pul_size_out)
{
	FS_ADAPT_get_free_space_f(_pc_path_in, _pul_size_out);
}

void FS_ADAPT_is_directory_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;
	UINT attributes;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		fs_err = fx_file_attributes_read(&g_fx_media, _pc_path_in, &attributes);

		/* test return function */
		if (fs_err == FX_NOT_A_FILE)
		{
			* _puc_bool_out = 0;
		}
		else
		{
			* _puc_bool_out = 1;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_is_file_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	unsigned char puc_bool_exist;
	unsigned char puc_bool_isdirectory;

	FS_ADAPT_exist_file_f(_pc_path_in, &puc_bool_exist);
	FS_ADAPT_is_directory_f(_pc_path_in, &puc_bool_isdirectory);

	/* if entity exist and not directory so it's a file */
	* _puc_bool_out = !((puc_bool_exist == 0) && (puc_bool_isdirectory == 1));
}

void FS_ADAPT_is_hidden_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fno;
	UINT fs_err;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		fs_err = fx_file_attributes_read(&g_fx_media,_pc_path_in, &fno);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;
		}
		else
		{
			* _puc_bool_out = (fno & FX_HIDDEN) ? 0 : 1;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_get_last_modified_f(char* _pc_path_in, int * _pi_data_out, unsigned char * _puc_bool_out)
{
	UINT attributes;
	UINT year;
	UINT month;
	UINT day;
	UINT hour;
	UINT minute;
	UINT second;
	ULONG size;
	UINT fs_err;

	/* test entry function */
	if ((_pc_path_in != NULL) && (_pi_data_out != NULL))
	{
		fs_err = fx_directory_information_get(&g_fx_media, _pc_path_in, &attributes, &size, &year, &month, &day,
				&hour, &minute, &second);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;
		}
		else
		{
			_pi_data_out[5] = (int) (second);
			_pi_data_out[4] = (int) (minute);
			_pi_data_out[3] = (int) (hour);
			_pi_data_out[2] = (int) (day);
			_pi_data_out[1] = (int) (month);
			_pi_data_out[0] = (int) (year);
			* _puc_bool_out = 0;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_mk_dir_f(const char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;

	#ifdef FS_ADAPT_DEBUG
	printf("FS_ADAPT_DEBUG [%s:%u] : create dir adaptation layer enter %p %s\n", __FILE__, __LINE__, _pc_path_in,_pc_path_in);
	#endif

	/* test entry function */
	if ((_pc_path_in != NULL) && (_puc_bool_out != NULL))
	{
		fs_err = fx_directory_create(&g_fx_media, (char*)_pc_path_in);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;
		}
		else
		{
			* _puc_bool_out = 0;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}

	#ifdef FS_ADAPT_DEBUG
	printf("FS_ADAPT_DEBUG [%s:%u] : create dir adaptation layer %s (status %u)\n", __FILE__, __LINE__, _pc_path_in, * _puc_bool_out );
	#endif
}
void FS_ADAPT_open_dir_f(char* _pc_path_in, int * _pi_fd_out)
{
	/* for fileX implementation there is no open dir concept, but
	 * we need to store the path and retrieve and id.
	 * This id is provide by POOL_reserve_f, and will be used
	 * to retrieve the path when next operation on directory will be called
	 */
	UINT fs_err;
	FS_ADAPT_DIR * m_dir;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		/* detect if path if root */
		if ((strcmp(_pc_path_in, "/") != 0) && (fx_directory_name_test(&g_fx_media, _pc_path_in) != FX_SUCCESS))
		{
			/* so path is not root and don't exist */
			*_pi_fd_out = LLFS_NOK;  // error
		}
		else
		{
			/* test if alloc is ok */
			if (POOL_reserve_f(&gst_pool_dir_ctx, (void**)&m_dir) == POOL_NO_ERROR)
			{
				/* store the path (or FX_NULL in case of root) and reset flag */
				strncpy(m_dir->path, (strcmp(_pc_path_in, "/") == 0) ? "\0" : _pc_path_in, sizeof(m_dir->path));
				m_dir->uc_first_search = 0;

				/* return address of object in pool as id */
				*_pi_fd_out = (int)m_dir;  // no error
			}
			else
			{
				*_pi_fd_out = LLFS_NOK;  // error
			}
		}
	}
	else
	{
		*_pi_fd_out = LLFS_NOK;  // error
	}
}

void FS_ADAPT_close_dir_f(unsigned int _ui_fd_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;
	int i_index;

	if (test_fd_among_dir_pool_f(_ui_fd_in, &i_index))
	{
		/* free file pool */
		POOL_free_f(&gst_pool_dir_ctx, (void*)_ui_fd_in);

		/* no error */
		_puc_bool_out = 0;
	}
	else
	{
		/* error fd not found */
		*_puc_bool_out = 1;

		#ifdef FS_ADAPT_PRINT_ERROR
			printf("FS_ADAPT_ERROR [%s:%u] close dir : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
		#endif
	}
}

void FS_ADAPT_read_dir_f(unsigned int _ui_fd_in,
						char* _pc_filename_in,
						unsigned char * _puc_bool_out)
{
	UINT fs_err;
	int i_index;

	/* test if fd is among open dir */
	if (test_fd_among_dir_pool_f(_ui_fd_in, &i_index))
	{
		/* set default path to pathname directory */
		//fs_err = fx_directory_default_set(&g_fx_media, gpst_pool_dir[i_index].path);
//		if (fs_err != FX_SUCCESS)
//		{
//			/* error cannot set default path */
//			*_puc_bool_out = 1;
//		}
//		else
//		{
			/* if first search */
			if (gpst_pool_dir[i_index].uc_first_search == 0)
			{
				/* read first entry */
				fx_directory_default_set(&g_fx_media, gpst_pool_dir[i_index].path);
				fs_err = fx_directory_first_entry_find(&g_fx_media, _pc_filename_in);
				gpst_pool_dir[i_index].uc_first_search = 1;
			}
			else
			{
				/* read next entry */
				fs_err = fx_directory_next_entry_find(&g_fx_media, _pc_filename_in);
			}
			/* test error */
			if (fs_err != FX_SUCCESS)
			{
				/* error or no more entry in directory */
				*_puc_bool_out = 1;
			}
			else
			{
				/* no error */
				*_puc_bool_out = 0;
			}

			/* restore default path (don't care about error) */
//			fx_directory_default_set(&g_fx_media, FX_NULL);
//		}
	}
	else
	{
		/* error fd not found */
		*_puc_bool_out = 1;
	}

#ifdef FS_ADAPT_PRINT_ERROR
	if (_puc_bool_out != 0)
	{
		//printf("FS_ADAPT_ERROR [%s:%u] read dir : fd (%u) not among file descriptor available\n",  __FILE__, __LINE__, _ui_fd_in);
	}
#endif
}

void FS_ADAPT_rename_f(char* _pc_old_name_in,
					  char* _pc_new_name_in,
					  unsigned char * _puc_bool_out)
{
	UINT fs_err;

	fs_err = fx_file_rename(&g_fx_media, _pc_old_name_in, _pc_new_name_in);

	fx_media_flush(&g_fx_media);

	if (fs_err != FX_SUCCESS)
	{
		* _puc_bool_out = 1;
	}
	else
	{
		* _puc_bool_out = 0;
	}
}

void FS_ADAPT_set_last_modified_f(char* _pc_path_in,
		                             int _i_years_in,
		                             int _i_month_in,
		                             int _i_day_in,
		                             int _i_hour_in,
		                             int _i_minute_in,
		                             int _i_second_in,
		                             unsigned char * _puc_bool_out)
{
	UINT fs_err;

	if (_pc_path_in != NULL)
	{

		fs_err = fx_file_date_time_set(&g_fx_media, _pc_path_in, _i_years_in,
				                       (UINT)_i_month_in, (UINT)_i_day_in, (UINT)_i_hour_in, (UINT)_i_minute_in, (UINT)_i_second_in);

		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;
		}
		else
		{
			* _puc_bool_out = 0;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_set_read_only_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		fs_err = fx_file_attributes_set(&g_fx_media,_pc_path_in, FX_READ_ONLY);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;
		}
		else
		{
			* _puc_bool_out = 0;
		}
	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_get_length_f(char* _pc_path_in, unsigned long * _pul_size_out)
{
	UINT fs_err;
	FS_ADAPT_FIL m_file;

	/* open file according to internal mode */
	fs_err = fx_file_open(&g_fx_media, &m_file, _pc_path_in, FX_OPEN_FOR_READ);

	/* test return function */
	if (fs_err != FX_SUCCESS)
	{
		*_pul_size_out = 0;  // error
	}
	else
	{
		*_pul_size_out = m_file.fx_file_current_file_size;

		fs_err = fx_file_close(&m_file);

		if (fs_err != FX_SUCCESS)
		{
			*_pul_size_out = 0;
		}
		else
		{
			/* nothing to do */
		}
	}
}

void FS_ADAPT_create_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;

  /* test entry function */
  if (_pc_path_in != NULL)
	{
		/* create file */
		fs_err = fx_file_create(&g_fx_media, _pc_path_in);

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 12;  // error
		}
		else
		{
			* _puc_bool_out = 0;
		}

		fx_media_flush(&g_fx_media);
	}
	else
	{
		* _puc_bool_out = 1;  // error
	}

	#ifdef FS_ADAPT_DEBUG
	printf("FS_ADAPT_DEBUG [%s:%u] : create item adaptation layer %s (status %u)\n", __FILE__, __LINE__, _pc_path_in, * _puc_bool_out );
	#endif
}

void FS_ADAPT_delete_f(char* _pc_path_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;

  /* test entry function */
  if (_pc_path_in != NULL)
	{
	    /* test if dir or file to delete */
	    if (fx_directory_name_test(&g_fx_media, _pc_path_in) == FX_SUCCESS)
	    {
			/* delete directory */
			fs_err = fx_directory_delete(&g_fx_media, _pc_path_in);
	    }
	    else
	    {
			/* delete file */
			fs_err = fx_file_delete(&g_fx_media, _pc_path_in);
	    }

		/* test return function */
		if (fs_err != FX_SUCCESS)
		{
			* _puc_bool_out = 1;  // error
		}
		else
		{
			* _puc_bool_out = 0;
		}

		fx_media_flush(&g_fx_media);
	}
	else
	{
		* _puc_bool_out = 1;  // error
	}
}

void FS_ADAPT_check_access_f(char* _pc_path_in, FS_access_t _access_in, unsigned char * _puc_bool_out)
{
	UINT fs_err;
	UINT attributes;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		switch (_access_in)
		{
			case (FS_ACCESS_READ):
			case (FS_ACCESS_WRITE):
			{
				fs_err = fx_file_attributes_read(&g_fx_media,_pc_path_in, &attributes);

				/* test return function */
				if ((fs_err != FX_SUCCESS) || ((attributes & FX_READ_ONLY) != 0))
				{
					* _puc_bool_out = 1;
				}
				else
				{
					* _puc_bool_out = 0;
				}

				break;
			}
			case (FS_ACCESS_EXECUTE):
			default:
				;
				/* nothing to do */
		}

	}
	else
	{
		* _puc_bool_out = 1;
	}
}

void FS_ADAPT_set_permission_f(char* _pc_path_in,
							   FS_access_t _access_in,
		                       unsigned char _uc_enable,
		                       unsigned char _uc_owner_only,
		                       unsigned char * _puc_bool_out)
{
	UINT fs_err;

	/* test entry function */
	if (_pc_path_in != NULL)
	{
		switch (_access_in)
		{
			case (FS_ACCESS_READ):
			case (FS_ACCESS_WRITE):
			{
				fs_err = fx_file_attributes_set(&g_fx_media,_pc_path_in, 0);

				/* test return function */
				if (fs_err != FX_SUCCESS)
				{
					* _puc_bool_out = 1;
				}
				else
				{
					* _puc_bool_out = 0;
				}

				fx_media_flush(&g_fx_media);

				break;
			}
			case (FS_ACCESS_EXECUTE):
			default:
				;
				/* nothing to do */
		}

	}
	else
	{
		* _puc_bool_out = 1;
	}
}

