/*
 * C
 *
 * Copyright 2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/* Includes ------------------------------------------------------------------*/

#include <stdint.h>
#include <stdio.h>
#include "LLHAL_GPIO_impl.h"
#include "microej.h"
#include "hal_data.h"
#include "microej_core.h"

/* Macros --------------------------------------------------------------------*/

/*
 * Check port and pin, update "gpio" struct
 */
#define __LLHAL_GPIO_IMPL_get_port_pin(port, pin, gpio)   do { \
        if (LLHAL_GPIO_IMPL_get_port_pin(port, pin, gpio) == HAL_GPIO_NOK) \
        return HAL_GPIO_NOK; /* invalid port or pin */ \
        } while (0)

/* Enum ----------------------------------------------------------------------*/

/*
 * List of ports used by this implementation
 */
typedef enum
{
    /*
     * Global virtual MCU port
     */
    LLHAL_GPIO_PORT_MCU = 0,

    /*
     * List of MCU ports used by this implementation
     */
    LLHAL_GPIO_PORT_0 = 1,
    LLHAL_GPIO_PORT_1 = 2,
    LLHAL_GPIO_PORT_2 = 3,
    LLHAL_GPIO_PORT_3 = 4,
    LLHAL_GPIO_PORT_4 = 5,
    LLHAL_GPIO_PORT_5 = 6,
    LLHAL_GPIO_PORT_6 = 7,
    LLHAL_GPIO_PORT_7 = 8,
    LLHAL_GPIO_PORT_8 = 9,
    LLHAL_GPIO_PORT_9 = 10,
    LLHAL_GPIO_PORT_A = 11,
    LLHAL_GPIO_PORT_B = 12,

    /*
     * List of specific ports used by this implementation
     */
    LLHAL_GPIO_PORT_PMODA = 64,
    LLHAL_GPIO_PORT_PMODB = 65,

} HAL_GPIO_IMPL_Port;

/* Structs -------------------------------------------------------------------*/

/*
 * MCU pin identification
 */
typedef struct
{
    // port / pin data
    ioport_port_pin_t port_pin;

    // ADC data
    const adc_instance_t* adc;
    adc_register_t adc_reg_id;

    // DAC data
    const timer_instance_t* dac;
    uint8_t dac_pin;

} HAL_GPIO_IMPL_Pin;

/* Private functions ---------------------------------------------------------*/

static int32_t LLHAL_GPIO_IMPL_get_port_pin(int32_t port, int32_t pin, HAL_GPIO_IMPL_Pin* gpio)
{
    // reset ADC/DAC channel
    gpio->adc = NULL;
    gpio->dac = NULL;

    switch(port)
    {
        case LLHAL_GPIO_PORT_MCU:
        {
            /*
             * MCU virtual port: convert port and pin using real MCU port and pin
             *
             * MCU port = pin / 16
             * MCU pin = pin % 16
             */

            if (pin < 0)
            {
                return HAL_GPIO_NOK;	// invalid pin
            }
            return LLHAL_GPIO_IMPL_get_port_pin(pin >> 4, pin & 0xf, gpio);
        }

        case LLHAL_GPIO_PORT_0:
        {
            switch(pin)
            {
                case 4:
                    // ADC and digital pin
                    gpio->adc = &hal_adc1_ch0;
                    gpio->adc_reg_id = ADC_REG_CHANNEL_0;
                    break;
                case 9:
                    // only digital pin
                    break;
                default:
                    // invalid pin
                    return HAL_GPIO_NOK;
            }
            break;
        }

        case LLHAL_GPIO_PORT_4:
        {
            switch(pin)
            {
                case 0:
                    // PWM and digital pin
                    gpio->dac = &hal_dac_ch6;
                    gpio->dac_pin = 0;  // A
                    break;
                default:
                    // invalid pin
                    return HAL_GPIO_NOK;
            }
            break;
        }

        case LLHAL_GPIO_PORT_9:
        {
            switch(pin)
            {
                case 11:
                    // PWM and digital pin
                    gpio->dac = &hal_dac_ch8;
                    gpio->dac_pin = 1;  // B
                    break;
                case 12:
                    // PWM and digital pin
                    gpio->dac = &hal_dac_ch8;
                    gpio->dac_pin = 0;  // A
                    break;
                case 13:
                    // only digital pin
                    break;
                default:
                    // invalid pin
                    return HAL_GPIO_NOK;
            }
            break;
        }

        case LLHAL_GPIO_PORT_B:
        {
            switch(pin)
            {
                case 2:
                case 3:
                    // only digital pin
                    break;
                default:
                    // invalid pin
                    return HAL_GPIO_NOK;
            }
            break;
        }

        case LLHAL_GPIO_PORT_PMODA:
        {
            /*
             * PMODA port: convert port and pin using MCU port and pin
             */
            switch(pin)
            {
                case 1:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_B, 2, gpio);
                // pin 2 and 3 are used by LLCOMM_UART
                //		case 2:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_B, 4, gpio);
                //		case 3:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_B, 5, gpio);
                case 4:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_B, 3, gpio);
                case 7:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_0, 4, gpio);
                case 8:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_9, 11, gpio);
                case 9:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_9, 12, gpio);
                case 10:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_9, 13, gpio);
                default:	return HAL_GPIO_NOK;	// invalid pin
            }
            break;
        }

        case LLHAL_GPIO_PORT_PMODB:
        {
            /*
             * PMODB port: convert port and pin using MCU port and pin
             */
            switch(pin)
            {
                case 1:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_0, 9, gpio);
                // pin 2 and 3 are used by LLCOMM_UART
                //		case 2:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_4, 1, gpio);
                //		case 3:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_4, 2, gpio);
                case 4:		return LLHAL_GPIO_IMPL_get_port_pin(LLHAL_GPIO_PORT_4, 0, gpio);
                default:	return HAL_GPIO_NOK;	// invalid pin
            }
            break;
        }

        default:
            // invalid port
            return HAL_GPIO_NOK;
    }

    // store port and pin
    gpio->port_pin = ((port - 1) << 8) | pin;

    return HAL_GPIO_OK;
}

/* API -----------------------------------------------------------------------*/

int32_t LLHAL_GPIO_IMPL_setPinMode(int32_t port, int32_t pin, int32_t mode)
{
    HAL_GPIO_IMPL_Pin gpio;
    uint32_t cfg;

    // get GPIO port and pin
    __LLHAL_GPIO_IMPL_get_port_pin(port, pin, &gpio);

    if (gpio.adc != NULL)
    {
        // stop potential previous ADC scan
        gpio.adc->p_api->scanStop(gpio.adc->p_ctrl);
    }

    // get GPIO configuration
    switch (mode)
    {
        case LLHAL_GPIO_MODE_DIGITAL_INPUT:
            g_ioport.p_api->pinCfg(gpio.port_pin, IOPORT_CFG_PORT_DIRECTION_INPUT);
            break;

        case LLHAL_GPIO_MODE_DIGITAL_INPUT_PULLUP:
            g_ioport.p_api->pinCfg(gpio.port_pin, IOPORT_CFG_PORT_DIRECTION_INPUT | IOPORT_CFG_PULLUP_ENABLE);
            break;

        case LLHAL_GPIO_MODE_DIGITAL_OUTPUT:
            g_ioport.p_api->pinCfg(gpio.port_pin, IOPORT_CFG_PORT_DIRECTION_OUTPUT);
            break;

        case LLHAL_GPIO_MODE_ANALOG_INPUT:

            if (gpio.adc == NULL)
            {
                // specified port/pin does not target an ADC
                return HAL_GPIO_NOK;
            }

            // configure port/pin
            g_ioport.p_api->pinCfg(gpio.port_pin, IOPORT_CFG_ANALOG_ENABLE);

            // open ADC and start channel scanning
            gpio.adc->p_api->open(gpio.adc->p_ctrl, gpio.adc->p_cfg);
            gpio.adc->p_api->scanCfg(gpio.adc->p_ctrl, gpio.adc->p_channel_cfg);
            gpio.adc->p_api->scanStart(gpio.adc->p_ctrl);
            break;

        case LLHAL_GPIO_MODE_ANALOG_OUTPUT:
        {
            if (gpio.dac == NULL)
            {
                // specified port/pin does not target a PWM
                return HAL_GPIO_NOK;
            }

            // configure port/pin
            g_ioport.p_api->pinCfg(gpio.port_pin, IOPORT_CFG_PERIPHERAL_PIN | IOPORT_PERIPHERAL_GPT1);

            // open DAC without starting it
            gpio.dac->p_api->open(gpio.dac->p_ctrl, gpio.dac->p_cfg);
            break;
        }
    }

    // no error
    return HAL_GPIO_OK;
}

int32_t LLHAL_GPIO_IMPL_getDigitalValue(int32_t port, int32_t pin)
{
    // get port/pin
    HAL_GPIO_IMPL_Pin gpio;
    __LLHAL_GPIO_IMPL_get_port_pin(port, pin, &gpio);

    // get GPIO level and return it
    ioport_level_t level;
    g_ioport.p_api->pinRead(gpio.port_pin, &level);
    return level == IOPORT_LEVEL_LOW ? LLHAL_GPIO_DIGITAL_LOW : LLHAL_GPIO_DIGITAL_HIGH;
}

int32_t LLHAL_GPIO_IMPL_setDigitalValue(int32_t port, int32_t pin, int32_t value)
{
    // get port/pin
    HAL_GPIO_IMPL_Pin gpio;
    __LLHAL_GPIO_IMPL_get_port_pin(port, pin, &gpio);

    // write GPIO level
    g_ioport.p_api->pinWrite(gpio.port_pin, value == LLHAL_GPIO_DIGITAL_LOW ? IOPORT_LEVEL_LOW : IOPORT_LEVEL_HIGH);

    // no error
    return HAL_GPIO_OK;
}

int32_t LLHAL_GPIO_IMPL_getAnalogValue(int32_t port, int32_t pin)
{
    // get port/pin and ADC data
    HAL_GPIO_IMPL_Pin gpio;
    __LLHAL_GPIO_IMPL_get_port_pin(port, pin, &gpio);

    if (gpio.adc == NULL)
    {
        // port/pin does not target an ADC
        return HAL_GPIO_NOK;
    }

    // read ADC value and return it
    adc_data_size_t value;
    gpio.adc->p_api->read(gpio.adc->p_ctrl, gpio.adc_reg_id, &value);
    return (int32_t)value;
}

int32_t LLHAL_GPIO_IMPL_setAnalogValue(int32_t port, int32_t pin, int32_t percentage)
{
    // get port/pin and DAC data
    HAL_GPIO_IMPL_Pin gpio;
    __LLHAL_GPIO_IMPL_get_port_pin(port, pin, &gpio);

    if (gpio.dac == NULL)
    {
        // port/pin does not target a DAC
        return HAL_GPIO_NOK;
    }

    // update duty cycle
    gpio.dac->p_api->dutyCycleSet(gpio.dac->p_ctrl, (timer_size_t)percentage, TIMER_PWM_UNIT_PERCENT, gpio.dac_pin);

    // start or restart
    gpio.dac->p_api->start(gpio.dac->p_ctrl);

    // no error
    return HAL_GPIO_OK;
}
