/*
 * C
 *
 * Copyright 2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */


#include 		<nx_bsd.h>
#include 		<nx_dhcp.h>
#include 		<nx_dns.h>
#include         "tx_api.h"
#include         "nx_api.h"
#include 		 "LLNET_Cfg.h"
#include         <string.h>
#include         <stdlib.h>
#include 		 "LLBSP_NET_impl.h"
#include		"LLNET_Util.h"
#include 		"device.h"
#include        "bsp_api.h"

/* Define the ThreadX and NetX object control blocks... */

NX_PACKET_POOL   bsd_pool;
NX_IP            llnet_nx_ip;
NX_DHCP          dhcp_client;
NX_DNS           dns;
ULONG 			 ip_address;
ULONG 			 ip_gateway;
ULONG 	  		 network_mask;
ULONG 			 dns_ip;

// variable used to notify that DNS servers list has changed
uint8_t dns_servers_list_updated = 1;

extern  VOID nx_ether_driver_eth1(NX_IP_DRIVER*);

VOID LLBSP_NET_dhcp_state_change_notify(NX_DHCP *dhcp_ptr, UCHAR new_state);
UINT LLBSP_NET_dns_static_config();
UINT LLBSP_NET_dns_dyn_config();
UINT LLBSP_NET_dns_set_ip();
UINT LLBSP_NET_ip_config_static();
UINT LLBSP_NET_ip_config_dyn();
VOID LLBSP_NET_ip_print();
UINT LLBSP_NET_create_nx_ip_instance();
VOID LLBSP_NET_ip_addr_update(NX_IP* ip_ptr, VOID* ip_additionnal_info_ptr);
VOID LLBSP_NET_mac_addr_config(NX_IP* ip_ptr);


/* Define the IP and the NetX BSD thread's stack area.  */
#define IP_THREAD_STACK_SIZE        4096
#define BSD_THREAD_STACK_SIZE       2048
static uint8_t ip_thread_stack[IP_THREAD_STACK_SIZE] BSP_PLACE_IN_SECTION(".stack.ip_thread");
static uint8_t bsd_thread_stack[BSD_THREAD_STACK_SIZE] BSP_PLACE_IN_SECTION(".stack.bsd_thread");

TX_SEMAPHORE llnet_dhcp_semaphore;

/* Define transmit packet pool for the demonstration.  */
#define NX_PACKET_PAYLOAD_SIZE  1536
#define NX_PACKET_POOL_SIZE     ((NX_PACKET_PAYLOAD_SIZE + sizeof(NX_PACKET)) * 36 * 4)

/* Add 32 to allow 32-byte alignment of rx buffers. */
/* Divide because this is a ULONG (not byte) array. */
ULONG	packet_pool_area[NX_PACKET_POOL_SIZE/sizeof(ULONG) + 32/sizeof(ULONG)];

/* Define the ARP cache area.  */
ULONG	arp_space_area[1024 / sizeof(ULONG)];

VOID LLBSP_NET_dhcp_state_change_notify(NX_DHCP *dhcp_ptr, UCHAR new_state)
{
	UINT    status;

	switch(new_state){
		case NX_DHCP_STATE_BOOT:
		case NX_DHCP_STATE_INIT:
		case NX_DHCP_STATE_SELECTING:
		case NX_DHCP_STATE_REQUESTING:
			break;
		case NX_DHCP_STATE_BOUND:
			/*check if static DNS configuration is requested by the user */
			if((((int32_t)&LLNET_DHCP_DNS_CONF) != LLNET_TRUE)){
				//get the static DNS address IP
				LLBSP_NET_dns_static_config();
			}else{
				/* DHCP DNS configuration is requested by the user*/
				LLBSP_NET_dns_dyn_config();
			}

		    // set DNS IP address
		    status = LLBSP_NET_dns_set_ip();
		    if(status)
		    {
		    	LLBSP_NET_TRACE("Error occurred during DNS address set (err=%d)", status);
		    }

	        status = tx_semaphore_put(&llnet_dhcp_semaphore);
	        if(status)
	        {
	            LLBSP_NET_TRACE("Error occurred when release DHCP semaphore (err=%d)\n", status);
	        }

		    // stop the DHCP instance
		    nx_dhcp_stop(&dhcp_client);
		    break;
		case NX_DHCP_STATE_RENEWING:
		case NX_DHCP_STATE_REBINDING:
		case NX_DHCP_STATE_FORCERENEW:
		default:
			break;
	}
}

UINT LLBSP_NET_dns_static_config()
{
	CHAR	*dns_ip_ptr;

	//get the static DNS address IP
	dns_ip_ptr = (CHAR*)LLNET_getDNSHostIPAddr();
	if(dns_ip_ptr != NULL)
	{
		dns_ip = inet_addr(dns_ip_ptr);
	}

	return 0;
}

UINT LLBSP_NET_dns_dyn_config()
{
	/* DHCP DNS configuration is requested by the user*/
	dns_ip = dhcp_client.nx_dhcp_DNS_server_address[0];

	return 0;
}


UINT LLBSP_NET_ip_config_static()
{
	UINT    status;
	ULONG 	dns_ip = 0;

	// set static IP settings
	ip_address = inet_addr((CHAR*)LLNET_getDeviceIPAddress());
	network_mask = inet_addr((CHAR*)LLNET_getDeviceNetmask());
	ip_gateway = inet_addr((CHAR*)LLNET_getDeviceGatewayIPAddr());
	nx_ip_gateway_address_set(&llnet_nx_ip, ip_gateway);

	return status;
}

VOID LLBSP_NET_ip_print()
{
	LLBSP_NET_TRACE("[INFO] IP address assigned: %d.%d.%d.%d\n",
		   (ip_address >> 24),
		   ((ip_address >> 16) & 0xFF),
		   ((ip_address >> 8) & 0xFF),
		   (ip_address & 0xFF));
}

UINT LLBSP_NET_ip_config_dyn()
{
	UINT    status;

	/* Create the DHCP client */
	status = nx_dhcp_create(&dhcp_client, &llnet_nx_ip, "DHCP Client");
	if(status)
	{
		LLBSP_NET_TRACE("Error occurred during DHCP client creation (err=%d)\n");
		return status;
	}

	status = nx_dhcp_state_change_notify(&dhcp_client, LLBSP_NET_dhcp_state_change_notify);
	if(status)
	{
		LLBSP_NET_TRACE("Error occurred during DHCP client creation (err=%d)\n");
		return status;
	}

	/* Start the DHCP Client.  */
	nx_dhcp_start(&dhcp_client);
	if (status)
	{
		LLBSP_NET_TRACE("Can't solve DHCP IP address\n");
		return status;
	}

	return status;
}

UINT LLBSP_NET_dns_set_ip()
{
	UINT    status;
    /* setup DNS server address*/
	if(dns_ip != 0 && NX_DNS_MAX_SERVERS > 0){

		// Create a DNS instance for the Client.
		status =  nx_dns_create(&dns, &llnet_nx_ip, "DNS Client");
		if (status){
			LLBSP_NET_TRACE("Can't create DNS instance\n");
			return status;
		}

		/* Add the IPv4 server address of the same DNS server to the Client list. */
		status = nx_dns_server_add(&dns, dns_ip);
		// notify DNS servers IP address updated
		dns_servers_list_updated = 1;
		/* Check for errors.  */
		if (status){
			LLBSP_NET_TRACE("Can't set DNS server Ir'P\n");
			return status;
		}
	}

	return 0;	// success
}

VOID LLBSP_NET_ip_addr_update(NX_IP* ip_ptr, VOID* ip_additionnal_info_ptr)
{
	UINT    status = 0;
	status = nx_ip_address_get(ip_ptr, &ip_address, &network_mask);
	if(status)
	{
		LLBSP_NET_TRACE("Error occurred during IP settings retrieve (err=%d)\n", status);
	}

	// update gateway IP address
	int32_t dhcpConfEnabled = ((int32_t)&LLNET_DHCP_CONF == LLNET_TRUE);
	if(dhcpConfEnabled){
		// set the gateway ip address
		nx_ip_gateway_address_set(ip_ptr, dhcp_client.nx_dhcp_gateway_address);
	}else{
		nx_ip_gateway_address_set(ip_ptr, ip_gateway);
	}
	ip_gateway = ip_ptr->nx_ip_gateway_address;

	// update LLNET IP address settings
	LLNET_setDeviceIPAddress((uint8_t*)(&ip_address));
	LLNET_setDeviceNetmask((uint8_t*)(&network_mask));
	LLNET_setDeviceGatewayIPAddr((uint8_t*)(&ip_gateway));
}

VOID LLBSP_NET_mac_addr_config(NX_IP* ip_ptr){
	uint8_t macaddress[6];

	parseMacAddr(LLNET_getMACAddr(), &macaddress[0], 0, 6);

	if(macaddress[3] == 0 && macaddress[4] == 0 && macaddress[5] == 0){
		// Consider only the prefix and generate an ID based on the mcu unique identifier
		uint32_t crc24 = computeCRC24(UNIQUE_DEVICE_ID_ADDRESS, UNIQUE_DEVICE_ID_SIZE);
		macaddress[3] = crc24 & 0xFF;
		macaddress[4] = (crc24>>8) & 0xFF;
		macaddress[5] = (crc24>>16) & 0xFF;
	}

	//get the most and the least significant word parts
	ULONG physical_address_msw = ((ULONG)macaddress[0] << 8 | (ULONG)macaddress[1]);
	ULONG physical_address_lsw = ((ULONG)macaddress[2] << 24 | (ULONG)macaddress[3] << 16 | (ULONG)macaddress[4] << 8 | (ULONG)macaddress[5]);
	//setup the physical address
	ip_ptr -> nx_ip_interface[0].nx_interface_physical_address_msw = physical_address_msw;
	ip_ptr -> nx_ip_interface[0].nx_interface_physical_address_lsw = physical_address_lsw;
}

UINT LLBSP_NET_create_nx_ip_instance()
{
	UINT    status = 0;
	status = nx_ip_create(&llnet_nx_ip, "NX IP Instance", ip_address, network_mask,  &bsd_pool, nx_ether_driver_eth1,
					ip_thread_stack, IP_THREAD_STACK_SIZE, 1);
	if(status)
	{
		LLBSP_NET_TRACE("Error occurred during NetX IP instance creation (err=%d)", status);
		return status;
	}

    // check if MAC address configuration is requested by MicroEJ workbench extension
    int32_t mac_conf_enabled = ((int32_t)&LLNET_MAC_CONF == LLNET_TRUE);
    if(mac_conf_enabled){
        //config the MAC address
        LLBSP_NET_mac_addr_config(&llnet_nx_ip);
    }

	// register to any ip address modification
	status = nx_ip_address_change_notify(&llnet_nx_ip, LLBSP_NET_ip_addr_update, NX_NULL);
	if(status){
		LLBSP_NET_TRACE("Error occurred during NetX IP address change notification registration (err=%d)", status);
		return status;
	}

	return status;
}

int32_t    LLBSP_NET_init()
{
	UINT    status;
	int32_t    error_counter = 0;
	CHAR	*dns_ip_ptr;

	LLBSP_NET_TRACE("[INFO] LLBSP_NET init\n");

	/* Initialize the NetX system.  */
    nx_system_initialize();

    /* Create a BSD packet pool.  */
    status =  nx_packet_pool_create(&bsd_pool, "NetX Main Packet Pool", NX_PACKET_PAYLOAD_SIZE,  (ULONG*)(((int)packet_pool_area + 31) & ~31) , NX_PACKET_POOL_SIZE);
    if (status)
    {
		error_counter++;
		LLBSP_NET_TRACE("Error in creating BSD packet pool\n!");
    }

    /* Create an IP instance for BSD.  */
	int32_t dhcpConfEnabled = ((int32_t)&LLNET_DHCP_CONF == LLNET_TRUE);
	if(dhcpConfEnabled){
	    tx_semaphore_create(&llnet_dhcp_semaphore, "LLNET DHCP semaphore", 0);

		// set DHCP IP settings
		ip_address = IP_ADDRESS(0,0,0,0);
		network_mask = IP_ADDRESS(0,0,0,0);

		// create the NetX BSD intance
		status = LLBSP_NET_create_nx_ip_instance();
		if(status)
		{
	        error_counter++;
			LLBSP_NET_TRACE("Error occurred during NetX BSD instance creation (err=%d)\n", status);
		}
	}else{
		LLBSP_NET_ip_config_static();
	    if (status)
	    {
	        error_counter++;
	        LLBSP_NET_TRACE("Error occurred during static IP configuration (err=%d)\n", status);
	    }

	    // create the NetX IP intance
		status = LLBSP_NET_create_nx_ip_instance();
		if(status)
		{
	        error_counter++;
			LLBSP_NET_TRACE("Error occurred during NetX BSD instance creation (err=%d)\n", status);
		}

		// force IP settings update
		LLBSP_NET_ip_addr_update(&llnet_nx_ip, NULL);
	}

    /* Enable ARP and supply ARP cache memory for BSD IP Instance */
    status =  nx_arp_enable(&llnet_nx_ip, (void *)arp_space_area, sizeof(arp_space_area));
    /* Check ARP enable status.  */     
    if (status)
    {
        error_counter++;
        LLBSP_NET_TRACE("Error in Enable ARP and supply ARP cache memory to BSD IP instance (err=%d)\n", status);
    }   

    /* Enable TCP processing for BSD IP instances.  */
    status = nx_tcp_enable(&llnet_nx_ip);
    /* Check TCP enable status.  */
    if (status)
    {
        error_counter++;
        LLBSP_NET_TRACE("Error in Enable TCP (err=%d)\n", status);
    }   

    /* Enable UDP traffic.  */
    status =  nx_udp_enable(&llnet_nx_ip);
    /* Check for UDP enable errors.  */
    if (status){
        error_counter++;
        LLBSP_NET_TRACE("Error in Enable UDP (err=%d)\n", status);
    }

    /* Enable ICMP.  */
	status =  nx_icmp_enable(&llnet_nx_ip);
	 if (status){
		 error_counter++;
		 LLBSP_NET_TRACE("Error in Enable ICMP (err=%d)\n", status);
	 }

	 /* Enable IP fragmentation.  */
	 status =  nx_ip_fragment_enable(&llnet_nx_ip);
	 if (status){
		 error_counter++;
		 LLBSP_NET_TRACE("Error in Enable IP fragmentation (err=%d)\n", status);
	 }


	 if(dhcpConfEnabled){
		// launch DHCP
    	LLBSP_NET_ip_config_dyn();

		status = tx_semaphore_get(&llnet_dhcp_semaphore, TX_WAIT_FOREVER);
		if(status)
		{
			error_counter++;
			LLBSP_NET_TRACE("Error occurred when waiting on DHCP semaphore (err=%d)\n");
			return error_counter;
		}
	}else{
		status = LLBSP_NET_dns_static_config(&dns_ip);
		if (status)
		{
			error_counter++;
			LLBSP_NET_TRACE("Error during static DNS IP retrieve (err=%d)\n", status);
		}

		status = LLBSP_NET_dns_set_ip(&dns_ip);
		if (status)
		{
			error_counter++;
			LLBSP_NET_TRACE("Error during static DNS IP set (err=%d)\n", status);
		}
	}

    /* Now initialize BSD Socket Wrapper */
    status = bsd_initialize (&llnet_nx_ip, &bsd_pool, (CHAR*)bsd_thread_stack, BSD_THREAD_STACK_SIZE, 2);

    /* Check NetX BSD initialization status.  */
    if (status)
    {
        error_counter++;
        LLBSP_NET_TRACE("NetX BSD initialization error \n");
    }

	// print IP address
	LLBSP_NET_ip_print();

    return error_counter;
}
