/*
 * C
 *
 * Copyright 2014-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
#include <LLNET_CHANNEL_impl.h>
#include <nx_bsd.h>

#include <string.h>
#include "LLNET_CONSTANTS.h"
#include "LLDISPATCH_CONSTANTS.h"
#include "LLDISPATCH_EVENT.h"
#include "LLNET_Util_netx.h"
#include "LLNET_ERRORS.h"

#ifdef __cplusplus
	extern "C" {
#endif


extern void __iceTea__componentInit_dispatch_7events(void);

extern int32_t map_to_java_exception(int32_t err);

int32_t LLNET_CHANNEL_IMPL_close(int32_t fd, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd);

	// check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

	if(soc_close(fd) == -1){
		return map_to_java_exception(errno);
	}
	return 0;
}
int32_t LLNET_CHANNEL_IMPL_initialize(void)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);
	__iceTea__componentInit_dispatch_7events(); // init LLDISPATCH IceTea component

	return 0;
}
int32_t LLNET_CHANNEL_IMPL_setBlocking(int32_t fd, uint8_t blocking, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, blocking=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, blocking);

    // check if NetX is initialized before call stack function
	if(!LLNET_initialized()){
	    return J_NETWORK_NOT_INITIALIZED;
	}

	int32_t opts = fcntl(fd, F_GETFL, 0);
	if(opts >= 0){
		if(fcntl(fd, F_SETFL, blocking? (opts &= ~O_NONBLOCK) : (opts |= O_NONBLOCK)) == 0){
			return 0;
		}
	}
	return map_to_java_exception(errno);
}

int32_t LLNET_CHANNEL_IMPL_shutdown(int32_t fd, uint8_t retry)
{
	//nothing to do
	//shutdown is called from java just before the close operation
	//the close operation will do the job.
    return 0;
}

int32_t LLNET_CHANNEL_IMPL_bind(int32_t fd, int8_t* addr, int32_t offset, int32_t length, int32_t port, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, port=%d,...)\n", __func__, SNI_getCurrentJavaThreadID(), fd, port);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

	struct sockaddr_in sockaddr;
	memset(&sockaddr, 0, sizeof(sockaddr));
	sockaddr.sin_family = AF_INET;
	sockaddr.sin_port = htons(port);

	uint32_t netx_addr = *((uint32_t*)addr);

	NX_CHANGE_ULONG_ENDIAN(netx_addr);

	sockaddr.sin_addr.s_addr = netx_addr;

	int32_t ret = bind(fd, (struct sockaddr*)&sockaddr, sizeof(struct sockaddr_in));
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, errno=%d, ...)\n", __func__, SNI_getCurrentJavaThreadID(), fd, errno);
	if(ret == -1){
		return map_to_java_exception(errno);
	}
	return 0;
}
int32_t LLNET_CHANNEL_IMPL_getOption(int32_t fd, int32_t option, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, option);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

	int32_t optname = -1;
	int32_t level = SOL_SOCKET;
	int32_t optlen = sizeof(int32_t);
	int32_t optVal;
	struct timeval sock_timeout;
	void* p_optVal = &optVal;

	switch (option) {
		case CPNET_SO_KEEPALIVE:
			optname = SO_KEEPALIVE;
			break;
		case CPNET_SO_BROADCAST:
			optname = SO_BROADCAST;
			break;
		case CPNET_SO_TIMEOUT :
			p_optVal = &sock_timeout;
			optlen = sizeof(sock_timeout);
			optname = SO_RCVTIMEO;
			break;
		case CPNET_SO_RCVBUF :
			optname = SO_RCVBUF;
			break;
		case CPNET_TCP_NODELAY:
			level = IPPROTO_TCP;
			optname = TCP_NODELAY;
			break;
		case CPNET_SO_REUSEADDR :
			optname = SO_REUSEADDR;
			break;
		case CPNET_SO_SNDBUF : //unsupported SO_SNDBUF option
		case CPNET_IP_TOS: //no traffic class support for this implementation
		case CPNET_SO_OOBINLINE:	// no urgent data option for this implementation
		case CPNET_IP_MULTICAST_LOOP: //unsupported IP_MULTICAST_LOOP option
		default:
			//option not available
			return J_ENOPROTOOPT;
	}

	int32_t res = getsockopt(fd, level, optname, p_optVal, (int32_t *)&optlen);
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d) res=%d errno=%d\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, res, errno);
	if(res == -1){
		return map_to_java_exception(errno);
	}

	if(option == CPNET_SO_TIMEOUT){
		return (sock_timeout.tv_usec / 1000) + (sock_timeout.tv_sec * 1000);
	}

	return optVal;
}
int32_t LLNET_CHANNEL_IMPL_setOption(int32_t fd, int32_t option, int32_t value, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d, value=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, value);
	int32_t optname = -1;
	int32_t level = SOL_SOCKET;
	struct timeval sock_timeout;
	
	int32_t optlen = sizeof(int32_t);
	
    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }
		
	void* p_optval = &value;

	switch (option) {
		case CPNET_SO_KEEPALIVE:
			optname = SO_KEEPALIVE;
			break;
		case CPNET_SO_BROADCAST:
			optname = SO_BROADCAST;
			break;
		case CPNET_SO_TIMEOUT:
			if(value > 1000){
				sock_timeout.tv_sec = value / 1000;
				sock_timeout.tv_usec = (value % 1000) * 1000;
			}else{
				sock_timeout.tv_sec = 0;
				sock_timeout.tv_usec = value * 1000;
			}
			p_optval = &sock_timeout;
			optlen = sizeof(sock_timeout);
			optname = SO_RCVTIMEO;
			break;
		case CPNET_SO_RCVBUF:
			optname = SO_RCVBUF;
			break;
		case CPNET_TCP_NODELAY:
			level = IPPROTO_TCP;
			optname = TCP_NODELAY;
			break;
		case CPNET_SO_REUSEADDR :
			optname = SO_REUSEADDR;
			break;
		case CPNET_SO_SNDBUF : //unsupported SO_SNDBUF option
		case CPNET_IP_TOS: //no traffic class support for this implementation
		case CPNET_SO_OOBINLINE:	// no urgent data option for this implementation
		case CPNET_IP_MULTICAST_LOOP: //unsupported IP_MULTICAST_LOOP option
		default:
			/* option not available */
			return J_ENOPROTOOPT;
	}
	int32_t res = setsockopt (fd, level, optname, p_optval, optlen);
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d, value=%d), res=%d, errno=%d\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, value, res, errno);
	if (res == -1) {
		return map_to_java_exception(errno);
	}
	return 0;
}
int32_t LLNET_CHANNEL_IMPL_getOptionAsByteArray(int32_t fd, int32_t option, int8_t* dst, int32_t dstOffset, int32_t dstLength, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d, dstLength=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, dstLength);

	switch (option) {
		case CPNET_IP_MULTICAST_IF:
		case CPNET_IP_MULTICAST_IF2:
			{
				struct in_addr addr;
				socklen_t len;
				int32_t res = getsockopt(fd, IPPROTO_IP, IP_MULTICAST_IF, &addr, &len);
				LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d) res=%d errno=%d\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, res, errno);
				if(res == -1){
					return map_to_java_exception(errno);
				}
				*((int32_t*)(dst + dstOffset)) = *((int32_t*)&addr.s_addr);
				return sizeof(int32_t);
			}
		default:
			//option not available
			return J_ENOPROTOOPT;
	}
}
int32_t LLNET_CHANNEL_IMPL_setOptionAsByteArray(int32_t fd, int32_t option, int8_t* value, int32_t valueOffset, int32_t valueLength, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d, valueLength=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, valueLength);
	switch (option) {
		case CPNET_IP_MULTICAST_IF:
		case CPNET_IP_MULTICAST_IF2:
			{
				struct in_addr addr;
				int32_t res;
				*((int32_t*)&addr.s_addr) = *((int32_t*)(value + valueOffset));
				res = setsockopt(fd, IPPROTO_IP, IP_MULTICAST_IF, &addr, sizeof(addr));
				LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, option=%d) res=%d errno=%d\n", __func__, SNI_getCurrentJavaThreadID(), fd, option, res, errno);
				if(res == -1){
					return map_to_java_exception(errno);
				}
				return 0;
			}
		default:
			/* option not available */
			return J_ENOPROTOOPT;
	}
}
int32_t LLNET_CHANNEL_IMPL_listen(int32_t fd, int32_t backlog, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s[thread %d](fd=%d, backlog=%d)\n", __func__, SNI_getCurrentJavaThreadID(), fd, backlog);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

	int32_t res = listen(fd, backlog);
	if(res == -1){
		return map_to_java_exception(errno);
	}
	return 0;
}

//-----------------------------
//	Internal API
//-----------------------------
int32_t NonBlocking_Select(int32_t fd, int32_t operation){
	struct timeval zero_timeout;
	zero_timeout.tv_sec = 0;
	zero_timeout.tv_usec = 0;
	fd_set io_fds;
	fd_set err_fds;
	fd_set empty_fds;
	FD_ZERO(&io_fds);
	FD_ZERO(&err_fds);
	FD_ZERO(&empty_fds);
	FD_SET(fd, &io_fds);
	int32_t selectRes = -1;
	if(operation == LLDISPATCH_CONSTANTS_REQUEST_READ){
		selectRes = select(fd+1, &io_fds, &empty_fds, &err_fds, &zero_timeout);
	}else if(operation == LLDISPATCH_CONSTANTS_REQUEST_WRITE){
		selectRes = select(fd+1, &empty_fds, &io_fds, &err_fds, &zero_timeout);
	}else{
		//unsupported IO/Operation
		LLNET_DEBUG_ASSERT("%s: wrong operation == %d!\n", __func__, operation);
	}

	return selectRes;
}

#ifdef __cplusplus
	}
#endif
