/*
 * C
 *
 * Copyright 2014-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
#include <LLNET_DNS_impl.h>
#include <nx_bsd.h>

#include <string.h>
#include "LLNET_CONSTANTS.h"
#include "nx_dns.h"
#include "LLNET_Util_netx.h"
#include "LLNET_ERRORS.h"

/* The global DNS client instance. */
extern NX_DNS *_nx_dns_instance_ptr;
#define NX_DNS_INIT_CHECK	 if(_nx_dns_instance_ptr == NULL){ \
		return J_EHOSTUNKNOWN; }

int32_t LLNET_DNS_IMPL_getHostByAddr(int8_t* inOut, int32_t offset, int32_t length, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

    // check if the NetX DNS is initialized
	NX_DNS_INIT_CHECK

	struct sockaddr_in addr;
	addr.sin_family = AF_INET;

	uint32_t netx_addr = *((uint32_t*)inOut);

	NX_CHANGE_ULONG_ENDIAN(netx_addr);

	addr.sin_addr.s_addr = netx_addr;
	int32_t  res = getnameinfo((struct sockaddr *)&addr, sizeof(struct sockaddr_in),inOut, length, NULL, 0, 0);
	if(res != 0){
		return J_EHOSTUNKNOWN;
	}
	return 0;
}

int32_t LLNET_DNS_IMPL_getHostByNameAt(int32_t index, int8_t* inOut, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

    // check if the NetX DNS is initialized
	NX_DNS_INIT_CHECK

	struct addrinfo *addrs, *addr;
	struct addrinfo hints;
	memset(&hints, 0, sizeof(hints));
	hints.ai_family = AF_INET;
	hints.ai_socktype = SOCK_STREAM;

	int32_t  res = getaddrinfo(inOut, NULL, &hints, &addrs);
	if(res != 0){
		return J_EHOSTUNKNOWN;
	}

	int32_t  addrIndex = -1;
	addr = addrs;
	while(addr != NULL){
		if(++addrIndex == index){
			//get the address
			memcpy(inOut, (int8_t*)&(((struct sockaddr_in *)addr->ai_addr)->sin_addr.s_addr), 4);

			// freed address info pointer
			freeaddrinfo(addrs);
			return 4; //4 for IPv4 addr length
		}
		addr = addr->ai_next;
	}

	// freed address info pointer
	freeaddrinfo(addrs);
	return J_EHOSTUNKNOWN;
}

int32_t LLNET_DNS_IMPL_getHostByNameCount(int8_t* hostname, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED;
    }

    // check if the NetX DNS is initialized
	NX_DNS_INIT_CHECK

	struct addrinfo *addrs, *addr;
	struct addrinfo hints;
	int32_t  addrCount = 0;
	memset(&hints, 0, sizeof(hints));
	hints.ai_family = AF_INET;
	hints.ai_socktype = SOCK_STREAM;

	int32_t  res = getaddrinfo(hostname, NULL, &hints, &addrs);

	if(res != 0){
		return J_EHOSTUNKNOWN;
	}
	LLNET_DEBUG_TRACE("res=%d",res);

	addr = addrs;
	while(addr != NULL){
		++addrCount;
		addr = addr->ai_next;
	}

	// freed address info pointer
	freeaddrinfo(addrs);

	return addrCount;
}

