/*
 * C
 *
 * Copyright 2014-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
#include <LLNET_NETWORKINTERFACE_impl.h>
#include <nx_bsd.h>

#include <string.h>
#include <stdlib.h>
#include "LLNET_CONSTANTS.h"
#include "LLNET_Util_netx.h"

#ifdef __cplusplus
	extern "C" {
#endif

//the default IP instance for BSD use
extern NX_IP   *nx_bsd_default_ip;

int32_t LLNET_NETWORKINTERFACE_IMPL_getVMInterface(int32_t idIf, int8_t* nameReturned, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

	if(idIf >= 0 && idIf < NX_MAX_IP_INTERFACES){
        if( nx_bsd_default_ip -> nx_ip_interface[idIf].nx_interface_valid ){
            size_t len = strlen( nx_bsd_default_ip -> nx_ip_interface[idIf].nx_interface_name);
            // interface found, return the name
            memcpy(nameReturned,  nx_bsd_default_ip -> nx_ip_interface[idIf].nx_interface_name, len);
            nameReturned[len] = '\0'; //null terminated
            return len;
        }
	}
	// error: no interface found at the 'id' index
	return 0;
}

// v6 is not supported yet, but here are the v4 and v6 constants
// for the getVMInterfaceAddress protocol between Java and the native stacks

// ipv4 address info size (tag (1) + IP (4) + prefix (1) + hasBroadcast (1) + broadcast IP (4))
#define IPV4_ADDR_INFO_SIZE 11
// ipv6 address info size (tag (1) + IP (16) + prefix (1)
#define IPV6_ADDR_INFO_SIZE 18

// ipv4 address tag
#define IPV4_ADDR_TAG 4
// ipv6 address tag
#define IPV6_ADDR_TAG 6

static int32_t _getMaskLen(NX_INTERFACE *netif)
{
    int32_t len = 0;
    uint32_t mask = netif->nx_interface_ip_network_mask;
    while (mask) {
        mask <<= 1;
        len++;
    }
    return len;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_getVMInterfaceAddress(int32_t idIf, int32_t idAddr, int8_t* addr, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

	if(idIf >= 0 && idIf < NX_MAX_IP_INTERFACES){

		if(nx_bsd_default_ip -> nx_ip_interface[idIf].nx_interface_valid){
		    // interface found, return the configured ip address
            // 'idAddr' not take into account here because only one ip address
            // is configured per network interface
			int32_t pos = 0;
		    addr[pos++] = IPV4_ADDR_TAG;
			uint32_t if_addr = nx_bsd_default_ip -> nx_ip_interface[idIf].nx_interface_ip_address;
			addr[pos++] = (if_addr >> 24) & 0xFF;
			addr[pos++] = (if_addr >> 16) & 0xFF;
			addr[pos++] = (if_addr >> 8) & 0xFF;
			addr[pos++] = (if_addr) & 0xFF;
			addr[pos++] = _getMaskLen(&nx_bsd_default_ip -> nx_ip_interface[idIf]);
			// now the broadcast,
			uint32_t broadcast =  (nx_bsd_default_ip->nx_ip_interface[idIf].nx_interface_ip_address) | ~(nx_bsd_default_ip->nx_ip_interface[idIf].nx_interface_ip_network_mask);
			addr[pos++] = 1;
			addr[pos++] = (broadcast >> 24) & 0xFF;
			addr[pos++] = (broadcast >> 16) & 0xFF;
			addr[pos++] = (broadcast >> 8) & 0xFF;
			addr[pos++] = (broadcast) & 0xFF;

			return IPV4_ADDR_INFO_SIZE;
		}
	}

	// error: no address found at the 'idAddr' index
	return 0;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_getVMInterfaceAddressesCount(int32_t id, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);
	return 1; // only one address configuration per network interface
}

int32_t LLNET_NETWORKINTERFACE_IMPL_getVMInterfacesCount(uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

	return NX_MAX_IP_INTERFACES;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_isLoopback(int8_t* name, int32_t offset, int32_t length, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

    // no loopback interface available
	return 1; // 1 means false
}

int32_t LLNET_NETWORKINTERFACE_IMPL_isPointToPoint(int8_t* name, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

	return 1;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_isUp(int8_t* name, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

	for(int32_t i = -1; ++i < NX_MAX_IP_INTERFACES;){
		if(strcmp(nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_name, name) == 0){
				if(nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_link_up){
					return 0; // 0 means true
				}
				return 1;// 1 means false
		}
	}
	return 1; // 1 means false
}

int32_t LLNET_NETWORKINTERFACE_IMPL_supportsMulticast(int8_t* name, int32_t offset, int32_t length, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

	return 1;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_getHardwareAddress(int8_t* name, int32_t offset, int32_t length, int8_t* hwAddr, int32_t hwAddrOffset, int32_t hwAddrMaxLength, uint8_t retry)
{
    LLNET_DEBUG_TRACE("%s\n", __func__);

    // check if NetX is initialized before call stack function
    if(!LLNET_initialized()){
        return J_NETWORK_NOT_INITIALIZED; // NetX not initialized
    }

	for(int32_t i = -1; ++i < NX_MAX_IP_INTERFACES;){

		if(strcmp(nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_name, name) == 0){
			int8_t * mac_addr = (int8_t*)hwAddr+hwAddrOffset;
			int8_t* physical_address_msw = (int8_t*)&nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_physical_address_msw;
			int8_t* physical_address_lsw = (int8_t*)&nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_physical_address_lsw;
			mac_addr[0] = physical_address_msw[1];
			mac_addr[1] = physical_address_msw[0];
			mac_addr[2] = physical_address_lsw[3];
			mac_addr[3] = physical_address_lsw[2];
			mac_addr[4] = physical_address_lsw[1];
			mac_addr[5] = physical_address_lsw[0];
			return 6;// 6 bytes for hardware address size
		}
	}
	// error: hardware address not found
	return 0;
}

int32_t LLNET_NETWORKINTERFACE_IMPL_getMTU(int8_t* name, int32_t offset, int32_t length, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);

	for(int32_t i = -1; ++i < NX_MAX_IP_INTERFACES;){
	    if(strcmp(nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_name, name) == 0){
	        return nx_bsd_default_ip -> nx_ip_interface[i].nx_interface_ip_mtu_size;
	    }
	}

	// hardware address not found
	return J_EUNKNOWN;
}

#ifdef __cplusplus
	}
#endif
