/*
 * C
 *
 * Copyright 2013-2016 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/* Includes ------------------------------------------------------------------*/

#include "microej.h"
#include "LLMJVM.h"
#include "buttons_helper.h"
#include "buttons_manager.h"
#include "microej_core.h"
#include "buttons_helper_configuration.h"

/* Defines --------------------------------------------------------------------*/

#define BUTTON_S1_IOPORT    IOPORT_PORT_00_PIN_06
#define BUTTON_S2_IOPORT    IOPORT_PORT_00_PIN_10
#define BUTTON_S3_IOPORT    IOPORT_PORT_00_PIN_11

/* Global --------------------------------------------------------------------*/

static const uint8_t BUTTON_PORT[NUMBER_OF_BUTTONS] = {BUTTON_S1_IOPORT, BUTTON_S2_IOPORT, BUTTON_S3_IOPORT};
static const uint8_t BUTTON_REVERSE[NUMBER_OF_BUTTONS] = {MICROEJ_FALSE, MICROEJ_FALSE, MICROEJ_FALSE};

/* Private API ---------------------------------------------------------------*/

static void BUTTONS_MANAGER_event(uint8_t buttonID)
{
	uint8_t button_pressed;
	ioport_level_t state;
	g_ioport.p_api->pinRead(BUTTON_PORT[buttonID], &state);

	if (state == IOPORT_LEVEL_LOW)
	{
		// GPIO == 1

		if (BUTTON_REVERSE[buttonID] == MICROEJ_TRUE)
		{
			// GPIO == 1 means "released"
			button_pressed = MICROEJ_FALSE;
		}
		else
		{
			// GPIO == 1 means "pressed"
			button_pressed = MICROEJ_TRUE;
			if(buttonID == BUTTON_S1_ID){
				LLMJVM_dump();
			}
		}
	}
	else
	{
		// GPIO == 0

		if (BUTTON_REVERSE[buttonID] == MICROEJ_TRUE)
		{
			// GPIO == 0 means "pressed"
			button_pressed = MICROEJ_TRUE;
		}
		else
		{
			// GPIO == 0 means "released"
			button_pressed = MICROEJ_FALSE;
		}
	}

	if (button_pressed == MICROEJ_TRUE)
	{
		BUTTONS_HELPER_pressed(buttonID);
	}
	else
	{
		BUTTONS_HELPER_released(buttonID);
	}
}

/** SSP callback implementation */

void button_s1_callback(external_irq_callback_args_t * p_args)
{
	BUTTONS_MANAGER_event(BUTTON_S1_ID);
}

void button_s2_callback(external_irq_callback_args_t * p_args)
{
	BUTTONS_MANAGER_event(BUTTON_S2_ID);
}

void button_s3_callback(external_irq_callback_args_t * p_args)
{
	BUTTONS_MANAGER_event(BUTTON_S3_ID);
}

static void BUTTONS_MANAGER_init()
{
    // Enable button S1
    g_button_S1.p_api->open(g_button_S1.p_ctrl, g_button_S1.p_cfg);
    g_button_S1.p_api->enable(g_button_S1.p_ctrl);

    // Enable button S2
    g_button_S2.p_api->open(g_button_S2.p_ctrl, g_button_S2.p_cfg);
    g_button_S2.p_api->enable(g_button_S2.p_ctrl);

    // Enable button S3
    g_button_S3.p_api->open(g_button_S3.p_ctrl, g_button_S3.p_cfg);
    g_button_S3.p_api->enable(g_button_S3.p_ctrl);
}

/* API -----------------------------------------------------------------------*/

void BUTTONS_MANAGER_interrupt(uint8_t buttonID)
{
	// no interrupt
}

void BUTTONS_MANAGER_enable_interrupts(void)
{
	// no interrupt
}

void BUTTONS_MANAGER_disable_interrupts(void)
{
	// no interrupt
}

void BUTTONS_MANAGER_initialize(void)
{
	BUTTONS_HELPER_initialize();
	BUTTONS_MANAGER_init();
}
