/*
 *  C
 *
 *  Copyright 2016 IS2T. All rights reserved.
 *  IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/* FS delegate entry function */
#include <stdio.h>
#include "fs_helper.h"
#include "fs_delegate_thread.h"
#include "fxconf.h"
#include "bsp_util.h"

#if (FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDRAM)
// declare File System SDRAM section
BSP_DECLARE_BUFFER(FS_MEM)

VOID _fx_ram_driver(FX_MEDIA *media_ptr);
#endif

extern uint8_t g_media_memory_g_fx_media[512];

ssp_err_t SF_EL_FX_MediaFormat (sf_block_media_format_t * p_sf_block_media_format)
{
    ssp_err_t ret_val = SSP_SUCCESS;
    uint32_t fx_ret_val;
    sf_block_media_instance_t * p_block_media;
    uint32_t sector_size;
    uint32_t sector_count;

    p_block_media = (sf_block_media_instance_t *) p_sf_block_media_format->p_driver_info->p_lower_lvl_block_media;

#if FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDMMC
    ret_val = p_block_media->p_api->open(p_block_media->p_ctrl, p_block_media->p_cfg);

    /* Get actual sector size from media. */
    if (SSP_SUCCESS == ret_val)
    {
        ret_val = p_block_media->p_api->ioctl(p_block_media->p_ctrl, SSP_COMMAND_GET_SECTOR_SIZE, &sector_size);
    }

    /* Get actual sector count from media. */
    if (SSP_SUCCESS == ret_val)
    {
        ret_val =
        p_block_media->p_api->ioctl(p_block_media->p_ctrl, SSP_COMMAND_GET_SECTOR_COUNT, &sector_count);
    }

    /* Close driver.  */
    if (SSP_SUCCESS == ret_val)
    {
        ret_val = p_block_media->p_api->close(p_block_media->p_ctrl);
    }
#else
    sector_count = p_sf_block_media_format->total_sectors;
    sector_size = p_sf_block_media_format->bytes_per_sector;
#endif

    /* If media operations were successful and memory size is as large as sector size, format media. */
    if ((SSP_SUCCESS == ret_val) && (!(p_sf_block_media_format->memory_size < sector_size)))
    {
        /* Format media.  */
        fx_ret_val = fx_media_format(p_sf_block_media_format->p_fx_media,       // Pointer to FileX media control block.
                SF_EL_FX_BlockDriver,// Driver entry
                p_sf_block_media_format->p_driver_info,// Pointer to Block Media Driver
                p_sf_block_media_format->p_memory,// Media buffer pointer
                p_sf_block_media_format->memory_size,// Media buffer size
                p_sf_block_media_format->volume_name,// Volume Name
                p_sf_block_media_format->number_of_fats,// Number of FATs
                p_sf_block_media_format->directory_entries,// Directory Entries
                p_sf_block_media_format->hidden_sectors,// Hidden sectors
                sector_count,// Total sectors
                sector_size,// Sector size
                p_sf_block_media_format->sectors_per_cluster,// Sectors per cluster
                1,// Heads
                1);// Sectors per track

        if (FX_SUCCESS != fx_ret_val)
        {
            ret_val = SSP_ERR_MEDIA_FORMAT_FAILED;
        }
    }
    else
    {
        ret_val = SSP_ERR_MEDIA_FORMAT_FAILED;
    }
    return ret_val;

}

#if (FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDRAM)
void fs_delegate_thread_entry_sdram(void){
    /* Initialize each kernel object and module instance. */
    ssp_err_t error;
    uint32_t fx_ret_val;
    uint8_t* fs_ram_buffer = (uint8_t*)FS_MEM_START;

//    memset(fs_ram_buffer, 0, FS_MEM_END - FS_MEM_START);

    fx_media_format(&g_fx_media,
                            _fx_ram_driver,         // Driver entry
                            fs_ram_buffer,        // RAM disk memory pointer
                            g_media_memory_g_fx_media,           // Media buffer pointer
                            sizeof(g_media_memory_g_fx_media),   // Media buffer size
                            "SDRAM_DISK",          // Volume Name
                            1,                      // Number of FATs
                            32,                     // Directory Entries
                            0,                      // Hidden sectors
                            32768,                    // Total sectors
                            128,                    // Sector size
                            1,                      // Sectors per cluster
                            1,                      // Heads
                            1);                     // Sectors per track

    fx_ret_val = fx_media_open(&g_fx_media, "sdram_disk", _fx_ram_driver,
            fs_ram_buffer, g_media_memory_g_fx_media,
            sizeof(g_media_memory_g_fx_media));
    if (fx_ret_val != FX_SUCCESS) {
        error = SSP_ERR_INTERNAL;
    }
}
#endif

#if (FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDMMC)
ssp_err_t fs_delegate_format_sdmmc(void) {
    ssp_err_t error;

    sf_block_media_format_t g_fx_media_format =
    {
        .p_fx_media = &g_fx_media,
        .p_driver_info = &g_sf_el_fx_cfg,
        .p_memory = g_media_memory_g_fx_media,
        .memory_size = sizeof(g_media_memory_g_fx_media),
        .volume_name = "Volume 1",
        .number_of_fats = 1,
        .directory_entries = 256,
        .hidden_sectors = 0,
        .total_sectors = 3751936,
        .bytes_per_sector = 512,
        .sectors_per_cluster = 1
    };

    error = SF_EL_FX_MediaFormat(&g_fx_media_format);

    if(error != SSP_SUCCESS)
    {
        error = SSP_ERR_MEDIA_FORMAT_FAILED;
    }
    return error;
}

void fs_delegate_thread_entry_sdmmc(void) {
    /* Initialize each kernel object and module instance. */
    ssp_err_t error;
    uint32_t fx_ret_val;

#if FS_DELEGATE_FX_FORMAT == 1
    error = fs_delegate_format_sdmmc();
    if(error != SSP_SUCCESS){
        /* media error */
    	printf("FS: Media format failed.\n");
        while(1);
    }
#endif

    fx_ret_val = fx_media_open(&g_fx_media, "g_fx_media", SF_EL_FX_BlockDriver,
          &g_sf_el_fx_cfg, g_media_memory_g_fx_media,
          sizeof(g_media_memory_g_fx_media));

    if (fx_ret_val != FX_SUCCESS)
    {
      /* if error try to format and reopen */
    	printf("FS: The media cannot be opened, try to format and reopen.\n");
      if(fs_delegate_format_sdmmc() != SSP_SUCCESS)
      {
          /* media error */
    	  printf("FS: Media format failed.\n");
          while(1);
      }
      else
      {
          fx_ret_val = fx_media_open(&g_fx_media, "g_fx_media", SF_EL_FX_BlockDriver,
                  &g_sf_el_fx_cfg, g_media_memory_g_fx_media,
                  sizeof(g_media_memory_g_fx_media));

          if (fx_ret_val != FX_SUCCESS)
          {
        	  printf("FS: After format, the media cannot be opened.\n");
              while(1);
          }
          else
          {
              /* nothing to do */
          }
      }
    }
}
#endif

void fs_delegate_thread_entry(void) {
    fx_system_initialize();

#if (FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDRAM)
    fs_delegate_thread_entry_sdram();
#elif (FS_DELEGATE_FX_MEDIA == FS_DELEGATE_FX_MEDIA_SDMMC)
    fs_delegate_thread_entry_sdmmc();
#else
#error "File System media unknown"
#endif

    while (1) {
        /* launch event consumer forever */
        FS_run_f();
    }
}
