
/*
 *	C
 *	
 *	Copyright 2015-2016 IS2T. All rights reserved.
 *	IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */


/* Includes ------------------------------------------------------------------*/

#include <stdio.h>
#include "touch_helper.h"
#include "touch_extension.h"
#include "touch_thread.h"
#include "sf_touch_panel_api.h"
#include "sf_message_port.h"
#include "LLDISPLAY_configuration.h"

/* Defines -------------------------------------------------------------------*/

#define TOUCH_WIDTH 480
#define TOUCH_HEIGHT 272

#ifdef LLDISPLAY_LOGICAL_WIDTH
#define TOUCH_LOGICAL_WIDTH LLDISPLAY_LOGICAL_WIDTH
#else
#define TOUCH_LOGICAL_WIDTH TOUCH_WIDTH
#endif

#ifdef LLDISPLAY_LOGICAL_HEIGHT
#define TOUCH_LOGICAL_HEIGHT LLDISPLAY_LOGICAL_HEIGHT
#else
#define TOUCH_LOGICAL_HEIGHT TOUCH_HEIGHT
#endif

#define TOUCH_MIN_X (((TOUCH_WIDTH) - (TOUCH_LOGICAL_WIDTH)) / 2)
#define TOUCH_MIN_Y (((TOUCH_HEIGHT) - (TOUCH_LOGICAL_HEIGHT)) / 2)
#define TOUCH_MAX_X ((TOUCH_MIN_X) + (TOUCH_LOGICAL_WIDTH) - 1)
#define TOUCH_MAX_Y ((TOUCH_MIN_Y) + (TOUCH_LOGICAL_HEIGHT) - 1)

#define TOUCH_IS_IN_BOUNDS(c, min, max) (((c) >= (min)) && ((c) <= (max)))
#define TOUCH_IS_VALID(x,y) (TOUCH_IS_IN_BOUNDS((x), (TOUCH_MIN_X), (TOUCH_MAX_X)) && TOUCH_IS_IN_BOUNDS((y), (TOUCH_MIN_Y), (TOUCH_MAX_Y)))
#define TOUCH_GET_X(x)  ((x) - (TOUCH_MIN_X))
#define TOUCH_GET_Y(y)  ((y) - (TOUCH_MIN_Y))

/* API -----------------------------------------------------------------------*/

void touch_thread_entry(void)
{
    ssp_err_t        err;
    sf_message_header_t * p_message = NULL;
    int16_t x,y;
    while(1)
    {
        g_sf_message.p_api->pend(g_sf_message.p_ctrl, &touch_thread_message_queue, (sf_message_header_t **) &p_message, TX_WAIT_FOREVER);

        switch (p_message->event_b.class)
        {
            case SF_MESSAGE_EVENT_CLASS_TOUCH:
            {
                switch (p_message->event_b.code)
                {
                    case SF_MESSAGE_EVENT_NEW_DATA:
                    {
                        sf_touch_panel_payload_t * p_touch_payload = (sf_touch_panel_payload_t * ) p_message;

                        /** interpret touch event */
                        switch (p_touch_payload->event_type)
                        {
                            case SF_TOUCH_PANEL_EVENT_DOWN:
                            case SF_TOUCH_PANEL_EVENT_HOLD:
                            case SF_TOUCH_PANEL_EVENT_MOVE:
                                x = p_touch_payload->x;
                                y = p_touch_payload->y;

#ifdef TOUCH_EXTENSION_ENABLED
                                touchPressedExtension(x, y);
#endif

                                if (TOUCH_IS_VALID(x, y))
                                {
                                    TOUCH_HELPER_pressed(TOUCH_GET_X(x), TOUCH_GET_X(y));
                                }
                                break;
                            case SF_TOUCH_PANEL_EVENT_UP:
                                TOUCH_HELPER_released();
                                break;
                            case SF_TOUCH_PANEL_EVENT_INVALID:
                                /* FIXME lot of event seems to be invalid (same in thermostat demo) */
                                break;
                            default:
                                printf("error touch\n");
                        }
                        break;
                    }
                    default:
                        break;
                }
                break;
            }
            default:
                break;
        }

        /** Message is processed, so release buffer. */
        err = g_sf_message.p_api->bufferRelease(g_sf_message.p_ctrl, (sf_message_header_t *) p_message, SF_MESSAGE_RELEASE_OPTION_FORCED_RELEASE);

        if (err)
        {
            while(1);
        }
    }
}
