/***********************************************************************************************************************
 * Copyright [2015] Renesas Electronics Corporation and/or its licensors. All Rights Reserved.
 * 
 * This file is part of Renesas SynergyTM Software Package (SSP)
 *
 * The contents of this file (the "contents") are proprietary and confidential to Renesas Electronics Corporation
 * and/or its licensors ("Renesas") and subject to statutory and contractual protections.
 *
 * This file is subject to a Renesas SSP license agreement. Unless otherwise agreed in an SSP license agreement with
 * Renesas: 1) you may not use, copy, modify, distribute, display, or perform the contents; 2) you may not use any name
 * or mark of Renesas for advertising or publicity purposes or in connection with your use of the contents; 3) RENESAS
 * MAKES NO WARRANTY OR REPRESENTATIONS ABOUT THE SUITABILITY OF THE CONTENTS FOR ANY PURPOSE; THE CONTENTS ARE PROVIDED
 * "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, AND NON-INFRINGEMENT; AND 4) RENESAS SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, OR
 * CONSEQUENTIAL DAMAGES, INCLUDING DAMAGES RESULTING FROM LOSS OF USE, DATA, OR PROJECTS, WHETHER IN AN ACTION OF
 * CONTRACT OR TORT, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE CONTENTS. Third-party contents
 * included in this file may be subject to different terms.
 **********************************************************************************************************************/
/**********************************************************************************************************************
* File Name    : sf_block_media_sdmmc.h
* Description  : Block Media for SDMMC header file.
***********************************************************************************************************************/


#ifndef R_BM_SDMMC_H
#define R_BM_SDMMC_H

/*******************************************************************************************************************//**
 * @file sf_block_media_sdmmc.h
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "bsp_api.h"
#include "sf_block_media_api.h"
#include "r_sdmmc_api.h"

/*******************************************************************************************************************//**
 * @ingroup SF_Library
 * @defgroup SF_BLOCK_MEDIA_SDMMC BLOCK_MEDIA_SDMMC
 * @brief RTOS-integrated Block Media framework for SDMMC driver.
 *
 * @{
 **********************************************************************************************************************/

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/
#define BLOCK_MEDIA_SDMMC_CODE_VERSION_MAJOR   (1)
#define BLOCK_MEDIA_SDMMC_CODE_VERSION_MINOR   (1)


/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/

typedef struct st_block_media_on_sdmmc_cfg
{
  sdmmc_instance_t     const  * const  p_lower_lvl_sdmmc;  ///< Pointer to SDMMC instance structure
} sf_block_media_on_sdmmc_cfg_t;

typedef struct st_block_media_on_sdmmc_ctrl
{
  sdmmc_instance_t                   * p_lower_lvl_sdmmc;  ///< Pointer to SDMMC instance structure
  TX_EVENT_FLAGS_GROUP                 eventflag;          ///< Pointer to the event flag object for SDMMC data transfer
} sf_block_media_on_sdmmc_ctrl_t;



/**********************************************************************************************************************
Exported global variables
***********************************************************************************************************************/
/** @cond INC_HEADER_DEFS_SEC */
extern const sf_block_media_api_t g_sf_block_media_on_sdmmc;
/** @endcond */

/**********************************************************************************************************************
Function Prototypes
***********************************************************************************************************************/



ssp_err_t SF_Block_Media_SDMMC_Open (sf_block_media_ctrl_t * const p_ctrl, sf_block_media_cfg_t const * const p_cfg);
ssp_err_t SF_Block_Media_SDMMC_Read (sf_block_media_ctrl_t * const p_ctrl, uint8_t * const p_dest, uint32_t const start_block, uint32_t const block_count);
ssp_err_t SF_Block_Media_SDMMC_Write (sf_block_media_ctrl_t * const p_ctrl, uint8_t const * const p_src, uint32_t const start_block, uint32_t const block_count);
ssp_err_t SF_Block_Media_SDMMC_Control (sf_block_media_ctrl_t * const p_ctrl, ssp_command_t const command, void * p_extend);
ssp_err_t SF_Block_Media_SDMMC_Close (sf_block_media_ctrl_t * const p_ctrl);
ssp_err_t SF_Block_Media_SDMMC_VersionGet (ssp_version_t * const p_version);

#endif // R_BM_SDMMC_H

/*******************************************************************************************************************//**
 * @} (end defgroup SF_BLOCK_MEDIA_SDMMC)
***********************************************************************************************************************/


