/***********************************************************************************************************************
 * Copyright [2015] Renesas Electronics Corporation and/or its licensors. All Rights Reserved.
 * 
 * This file is part of Renesas SynergyTM Software Package (SSP)
 *
 * The contents of this file (the "contents") are proprietary and confidential to Renesas Electronics Corporation
 * and/or its licensors ("Renesas") and subject to statutory and contractual protections.
 *
 * This file is subject to a Renesas SSP license agreement. Unless otherwise agreed in an SSP license agreement with
 * Renesas: 1) you may not use, copy, modify, distribute, display, or perform the contents; 2) you may not use any name
 * or mark of Renesas for advertising or publicity purposes or in connection with your use of the contents; 3) RENESAS
 * MAKES NO WARRANTY OR REPRESENTATIONS ABOUT THE SUITABILITY OF THE CONTENTS FOR ANY PURPOSE; THE CONTENTS ARE PROVIDED
 * "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, AND NON-INFRINGEMENT; AND 4) RENESAS SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, OR
 * CONSEQUENTIAL DAMAGES, INCLUDING DAMAGES RESULTING FROM LOSS OF USE, DATA, OR PROJECTS, WHETHER IN AN ACTION OF
 * CONTRACT OR TORT, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE CONTENTS. Third-party contents
 * included in this file may be subject to different terms.
 **********************************************************************************************************************/

/**********************************************************************************************************************
 * File Name    : hw_dmac_common.h
 * Description  : DMAC register access functions
 **********************************************************************************************************************/

#ifndef HW_DMAC_COMMON_H
#define HW_DMAC_COMMON_H

/**********************************************************************************************************************
 * Includes
 **********************************************************************************************************************/
#include "bsp_api.h"
#ifdef BSP_MCU_GROUP_S7G2
#include "..\..\..\src\driver\r_dmac\hw\target\s7g2\hw_dmac_s7g2.h"
#endif

#ifdef BSP_MCU_GROUP_S3A7
#include "..\..\..\src\driver\r_dmac\hw\target\s3a7\hw_dmac_s3a7.h"
#endif
/***********************************************************************************************************************
 * Macro definitions
 **********************************************************************************************************************/


/***********************************************************************************************************************
 * Typedef definitions
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * Private function prototypes
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * Private global variables
 **********************************************************************************************************************/
#if BSP_MCU_GROUP_S7G2
#endif

/***********************************************************************************************************************
 * Private Functions
 **********************************************************************************************************************/

/*******************************************************************************************************************//**
 * @brief Powers on DMAC block
 **********************************************************************************************************************/
__STATIC_INLINE void HW_DMAC_PowerOn (void)
{
    R_SYSTEM->MSTPCRA_b.MSTPA22 = 0;
}

__STATIC_INLINE void HW_DMAC_TransferEnableDisable (uint8_t ch, dmac_transfer_enable_t enable_disable)
{
    DMAC_CH(ch)->DMCNT_b.DTE = enable_disable;
}

__STATIC_INLINE elc_event_t HW_ICU_DmacEventGet (IRQn_Type irq)
{
    return (elc_event_t) R_ICU->IELSRn_b[irq].IELS;
}

__STATIC_INLINE void HW_ICU_DmacEnable (uint8_t ch, elc_event_t event)
{
    R_ICU->DELSRn[ch].DELSRn_b.DELS = event;
}

__STATIC_INLINE elc_event_t HW_ICU_DmacEnableGet (uint8_t ch)
{
    return (elc_event_t) R_ICU->DELSRn[ch].DELSRn_b.DELS;
}

__STATIC_INLINE void HW_DMAC_DestAddrUpdateModeSet (uint8_t ch, transfer_addr_mode_t mode)
{
    DMAC_CH(ch)->DMAMD_b.DM = mode;
}

__STATIC_INLINE void HW_DMAC_SrcAddrUpdateModeSet (uint8_t ch, transfer_addr_mode_t mode)
{
    DMAC_CH(ch)->DMAMD_b.SM = mode;
}

__STATIC_INLINE void HW_DMAC_DestExtendedRepeatAreaSet (uint8_t ch, dmac_extended_repeat_area_t size)
{
    DMAC_CH(ch)->DMAMD_b.DARA = size;
}

__STATIC_INLINE void HW_DMAC_SrcExtendedRepeatAreaSet (uint8_t ch, dmac_extended_repeat_area_t size)
{
    DMAC_CH(ch)->DMAMD_b.SARA = size;
}

__STATIC_INLINE void HW_DMAC_TransferRequestSourceSet (uint8_t ch, dmac_transfer_request_source_t src)
{
    DMAC_CH(ch)->DMTMD_b.DCTG = src;
}

__STATIC_INLINE void HW_DMAC_TransferSizeSet (uint8_t ch, transfer_size_t size)
{
    DMAC_CH(ch)->DMTMD_b.SZ = size;
}

__STATIC_INLINE void HW_DMAC_RepeatAreaSet (uint8_t ch, transfer_repeat_area_t repeat_area)
{
    DMAC_CH(ch)->DMTMD_b.DTS = repeat_area;
}

__STATIC_INLINE void HW_DMAC_ModeSet (uint8_t ch, transfer_mode_t mode)
{
    DMAC_CH(ch)->DMTMD_b.MD = mode;
}

__STATIC_INLINE transfer_mode_t HW_DMAC_ModeGet (uint8_t ch)
{
    return (transfer_mode_t) DMAC_CH(ch)->DMTMD_b.MD;
}

__STATIC_INLINE void HW_DMAC_SrcStartAddrSet (uint8_t ch, void const * volatile p_src)
{
    /* This is the source start address pointer, but it is represented by a uint32_t in the iodefine file.
     * Casting it to uint32_t. */
    DMAC_CH(ch)->DMSAR = (uint32_t) p_src;
}

__STATIC_INLINE void const * HW_DMAC_SrcStartAddrGet (uint8_t ch)
{
    /* This is the source start address pointer, but it is represented by a uint32_t in the iodefine file.
     * Casting it to pointer. */
    return (void const *) DMAC_CH(ch)->DMSAR;
}

__STATIC_INLINE void HW_DMAC_DestStartAddrSet (uint8_t ch, void * volatile p_dest)
{
    /* This is the destination start address pointer, but it is represented by a uint32_t in the iodefine file.
     * Casting it to uint32_t. */
    DMAC_CH(ch)->DMDAR = (uint32_t) p_dest;
}

__STATIC_INLINE void const * HW_DMAC_DestStartAddrGet (uint8_t ch)
{
    /* This is the destination start address pointer, but it is represented by a uint32_t in the iodefine file.
     * Casting it to pointer. */
    return (void const *) DMAC_CH(ch)->DMDAR;
}

__STATIC_INLINE void HW_DMAC_TransferNumberSet (uint8_t ch, uint16_t length)
{
    DMAC_CH(ch)->DMCRA_b.DMCRAL = length;
}

__STATIC_INLINE uint16_t HW_DMAC_TransferNumberGet (uint8_t ch)
{
    return (DMAC_CH(ch)->DMCRA_b.DMCRAL);
}

__STATIC_INLINE void HW_DMAC_TransferReloadSet (uint8_t ch, uint16_t length)
{
    /* Note: There is a warning here for GCC that will go away if length is cast to uint8_t.  The length parameter
     * is set into a 10 bit bitfield (DMCRAH), and casting to uint8_t will result in a change of value.  For this
     * reason, the warning is explicitly ignored in this case.
     */
#ifdef __GNUC__
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    DMAC_CH(ch)->DMCRA_b.DMCRAH = length;
#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif
}

__STATIC_INLINE void HW_DMAC_BlockNumberSet (uint8_t ch, uint16_t num_blocks)
{
    DMAC_CH(ch)->DMCRB = num_blocks;
}

__STATIC_INLINE uint16_t HW_DMAC_BlockNumberGet (uint8_t ch)
{
    return (DMAC_CH(ch)->DMCRB);
}

__STATIC_INLINE void HW_DMAC_TransferEndInterruptClear (uint8_t ch)
{
    DMAC_CH(ch)->DMSTS_b.DTIF = 0;
}

/*******************************************************************************************************************//**
 * Returns the IRQ number required for NVIC calls.
 * @param   ch           The channel corresponds to the hardware channel number.
 * @return  The IRQ number required for NVIC calls.
 **********************************************************************************************************************/
__STATIC_INLINE IRQn_Type HW_DMAC_IRQGet (uint8_t ch)
{
    return dmac_irq_lookup[ch];
}

/*******************************************************************************************************************//**
 * Clears interrupts for specified channel at ICU.
 * @param  irq_num       The channel corresponds to the hardware channel number.
 **********************************************************************************************************************/
__STATIC_INLINE void HW_DMAC_ICUInterruptClear (IRQn_Type irq_num)
{
    R_ICU->IELSRn_b[irq_num].IR = 0;
}

__STATIC_INLINE void HW_DMAC_TransferEndInterruptEnable (uint8_t ch)
{
    DMAC_CH(ch)->DMINT_b.DTIE = 1;
}

__STATIC_INLINE void HW_DMAC_TransferEndInterruptDisable (uint8_t ch)
{
    DMAC_CH(ch)->DMINT_b.DTIE = 0;
}

__STATIC_INLINE void HW_DMAC_SoftwareStart (uint8_t ch)
{
    DMAC_CH(ch)->DMREQ_b.SWREQ = 1;
}

__STATIC_INLINE void HW_DMAC_SoftwareStop (uint8_t ch)
{
    DMAC_CH(ch)->DMREQ_b.SWREQ = 0;
}

__STATIC_INLINE void HW_DMAC_SoftwareStartAutoClear (uint8_t ch, transfer_start_mode_t autoclear)
{
    DMAC_CH(ch)->DMREQ_b.CLRS = autoclear;
}

__STATIC_INLINE bool HW_DMAC_StatusGet (uint8_t ch)
{
    return DMAC_CH(ch)->DMSTS_b.ACT;
}

__STATIC_INLINE void HW_DMAC_Enable ()
{
    R_DMA->DMAST_b.DMST = 1;
}
#endif /* HW_DMAC_COMMON_H */
