/***********************************************************************************************************************
 * Copyright [2015] Renesas Electronics Corporation and/or its licensors. All Rights Reserved.
 * 
 * This file is part of Renesas SynergyTM Software Package (SSP)
 *
 * The contents of this file (the "contents") are proprietary and confidential to Renesas Electronics Corporation
 * and/or its licensors ("Renesas") and subject to statutory and contractual protections.
 *
 * This file is subject to a Renesas SSP license agreement. Unless otherwise agreed in an SSP license agreement with
 * Renesas: 1) you may not use, copy, modify, distribute, display, or perform the contents; 2) you may not use any name
 * or mark of Renesas for advertising or publicity purposes or in connection with your use of the contents; 3) RENESAS
 * MAKES NO WARRANTY OR REPRESENTATIONS ABOUT THE SUITABILITY OF THE CONTENTS FOR ANY PURPOSE; THE CONTENTS ARE PROVIDED
 * "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, AND NON-INFRINGEMENT; AND 4) RENESAS SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, OR
 * CONSEQUENTIAL DAMAGES, INCLUDING DAMAGES RESULTING FROM LOSS OF USE, DATA, OR PROJECTS, WHETHER IN AN ACTION OF
 * CONTRACT OR TORT, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE CONTENTS. Third-party contents
 * included in this file may be subject to different terms.
 **********************************************************************************************************************/

/**********************************************************************************************************************
 * File Name    : hw_dmac_private.h
 * Description  : DMAC register access function prototypes.
 **********************************************************************************************************************/

#ifndef HW_DMAC_PRIVATE_H
#define HW_DMAC_PRIVATE_H

/**********************************************************************************************************************
 * Includes
 **********************************************************************************************************************/
#include "r_dmac.h"
#include "bsp_api.h"

/**********************************************************************************************************************
 * Macro definitions
 **********************************************************************************************************************/
#ifdef BSP_MCU_GROUP_S3A7
#define DMAC_CHANNEL_MAX  (4)
#endif
#ifdef BSP_MCU_GROUP_S7G2
#define DMAC_CHANNEL_MAX  (8)
#endif

/**********************************************************************************************************************
 * Typedef definitions
 **********************************************************************************************************************/
typedef enum e_dmac_transfer_enable
{
    DMAC_TRANSFER_DISABLE = 0,
    DMAC_TRANSFER_ENABLE  = 1
} dmac_transfer_enable_t;

/** Select transfer request source (activates transfer). */
typedef enum e_dmac_transfer_request_source
{
    DMAC_TRANSFER_REQUEST_SOURCE_SOFTWARE,   ///< Start transfer in software
    DMAC_TRANSFER_REQUEST_SOURCE_INTERRUPT   ///< Start transfer by interrupt source
} dmac_transfer_request_source_t;

/** Extended repeat area. TODO_DMAC Add better description. */
typedef enum e_dmac_extended_repeat_area
{
    DMAC_EXTENDED_REPEAT_AREA_NONE       = 0,     ///< Extended repeat area unused
    DMAC_EXTENDED_REPEAT_AREA_2_BYTES    = 1,     ///< 2 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_4_BYTES    = 2,     ///< 4 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_8_BYTES    = 3,     ///< 8 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_16_BYTES   = 4,     ///< 16 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_32_BYTES   = 5,     ///< 32 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_64_BYTES   = 6,     ///< 64 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_128_BYTES  = 7,     ///< 128 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_256_BYTES  = 8,     ///< 256 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_512_BYTES  = 9,     ///< 512 byte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_1_KBYTE    = 10,    ///< 1 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_2_KBYTES   = 11,    ///< 2 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_4_KBYTES   = 12,    ///< 4 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_8_KBYTES   = 13,    ///< 8 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_16_KBYTES  = 14,    ///< 16 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_32_KBYTES  = 15,    ///< 32 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_64_KBYTES  = 16,    ///< 64 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_128_KBYTES = 17,    ///< 128 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_256_KBYTES = 18,    ///< 256 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_512_KBYTES = 19,    ///< 512 kilobyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_1_MBYTE    = 20,    ///< 1 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_2_MBYTES   = 21,    ///< 2 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_4_MBYTES   = 22,    ///< 4 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_8_MBYTES   = 23,    ///< 8 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_16_MBYTES  = 24,    ///< 16 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_32_MBYTES  = 25,    ///< 32 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_64_MBYTES  = 26,    ///< 64 megabyte extended repeat area
    DMAC_EXTENDED_REPEAT_AREA_128_MBYTES = 27     ///< 128 megabyte extended repeat area
} dmac_extended_repeat_area_t;

/**********************************************************************************************************************
 * Function Prototypes
 **********************************************************************************************************************/
__STATIC_INLINE void            HW_DMAC_PowerOn (void);

__STATIC_INLINE void            HW_DMAC_TransferEnableDisable (uint8_t         ch,
                                                               dmac_transfer_enable_t enable_disable);

__STATIC_INLINE elc_event_t     HW_ICU_DmacEventGet (IRQn_Type irq);

__STATIC_INLINE void            HW_ICU_DmacEnable (uint8_t ch, elc_event_t event);

__STATIC_INLINE elc_event_t     HW_ICU_DmacEnableGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_DestAddrUpdateModeSet (uint8_t ch, transfer_addr_mode_t mode);

__STATIC_INLINE void            HW_DMAC_SrcAddrUpdateModeSet (uint8_t ch, transfer_addr_mode_t mode);

__STATIC_INLINE void            HW_DMAC_DestExtendedRepeatAreaSet (uint8_t ch, dmac_extended_repeat_area_t size);

__STATIC_INLINE void            HW_DMAC_SrcExtendedRepeatAreaSet (uint8_t ch, dmac_extended_repeat_area_t size);

__STATIC_INLINE void            HW_DMAC_TransferRequestSourceSet (uint8_t                 ch,
                                                                  dmac_transfer_request_source_t src);

__STATIC_INLINE void            HW_DMAC_TransferSizeSet (uint8_t ch, transfer_size_t size);

__STATIC_INLINE void            HW_DMAC_RepeatAreaSet (uint8_t ch, transfer_repeat_area_t repeat_area);

__STATIC_INLINE void            HW_DMAC_ModeSet (uint8_t ch, transfer_mode_t mode);

__STATIC_INLINE transfer_mode_t HW_DMAC_ModeGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_SrcStartAddrSet (uint8_t ch, void const * volatile p_src);

__STATIC_INLINE void            HW_DMAC_DestStartAddrSet (uint8_t ch, void * volatile p_dest);

__STATIC_INLINE void            HW_DMAC_TransferNumberSet (uint8_t ch, uint16_t length);

__STATIC_INLINE uint16_t        HW_DMAC_TransferNumberGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_TransferReloadSet (uint8_t ch, uint16_t length);

__STATIC_INLINE void            HW_DMAC_BlockNumberSet (uint8_t ch, uint16_t num_blocks);

__STATIC_INLINE uint16_t        HW_DMAC_BlockNumberGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_TransferEndInterruptClear (uint8_t ch);

__STATIC_INLINE IRQn_Type       HW_DMAC_IRQGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_ICUInterruptClear (IRQn_Type irq_num);

__STATIC_INLINE void            HW_DMAC_TransferEndInterruptEnable (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_TransferEndInterruptDisable (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_SoftwareStart (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_SoftwareStop (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_SoftwareStartAutoClear (uint8_t ch, transfer_start_mode_t not_autoclear);

__STATIC_INLINE bool            HW_DMAC_StatusGet (uint8_t ch);

__STATIC_INLINE void            HW_DMAC_Enable ();

/**********************************************************************************************************************
 * Includes
 **********************************************************************************************************************/
/* Select implementation based on BSP here */
#include "common/hw_dmac_common.h"
#endif /* HW_DMAC_PRIVATE_H */

/*******************************************************************************************************************//**
 * @} (end addtogroup DMAC)
 **********************************************************************************************************************/
